@@ -16,14 +16,14 @@
 import pprint
 import time
 
-from oslo_config import cfg
-from oslo_log import log as logging
-from oslo_serialization import jsonutils as json
-from oslo_utils import importutils
 import requests
+from oslo.config import cfg
+from oslo_log import log as logging
+from oslo.serialization import jsonutils as json
+from oslo_utils import importutils
 
-from designate.backend import base
 from designate import exceptions
+from designate.backend import base
 from designate.i18n import _LE
 
 
@@ -62,12 +62,7 @@ rectype2iparectype = {'A': ('arecord', '%(data)s'),
                       'NS': ('nsrecord', '%(data)s'),
                       'PTR': ('ptrrecord', '%(data)s'),
                       'SPF': ('spfrecord', '%(data)s'),
-                      'SSHFP': ('sshfprecord', '%(data)s'),
-                      'NAPTR': ('naptrrecord', '%(data)s'),
-                      'CAA': ('caarecord', '%(data)s'),
-                      'CERT': ('certrecord', '%(data)s'),
-                      }
-
+                      'SSHFP': ('sshfprecord', '%(data)s')}
 
 IPA_INVALID_DATA = 3009
 IPA_NOT_FOUND = 4001
@@ -162,13 +157,13 @@ class IPABackend(base.Backend):
                        help='IPA RPC listener host - must be FQDN'),
             cfg.IntOpt('ipa-port', default=IPA_DEFAULT_PORT,
                        help='IPA RPC listener port'),
-            cfg.StrOpt('ipa-client-keytab',
+            cfg.StrOpt('ipa-client-keytab', default=None,
                        help='Kerberos client keytab file'),
             cfg.StrOpt('ipa-auth-driver-class',
                        default='designate.backend.impl_ipa.auth.IPAAuth',
                        help='Class that implements the authentication '
                        'driver for IPA'),
-            cfg.StrOpt('ipa-ca-cert',
+            cfg.StrOpt('ipa-ca-cert', default=None,
                        help='CA certificate for use with https to IPA'),
             cfg.StrOpt('ipa-base-url', default='/ipa',
                        help='Base URL for IPA RPC, relative to host[:port]'),
@@ -194,9 +189,9 @@ class IPABackend(base.Backend):
         self.request = requests.Session()
         authclassname = cfg.CONF[self.name].ipa_auth_driver_class
         authclass = importutils.import_class(authclassname)
-        self.request.auth = (
+        self.request.auth = \
             authclass(cfg.CONF[self.name].ipa_client_keytab,
-                      cfg.CONF[self.name].ipa_host))
+                      cfg.CONF[self.name].ipa_host)
         ipa_base_url = cfg.CONF[self.name].ipa_base_url
         if ipa_base_url.startswith("http"):  # full URL
             self.baseurl = ipa_base_url
@@ -218,11 +213,11 @@ class IPABackend(base.Backend):
         self.ntries = cfg.CONF[self.name].ipa_connect_retries
         self.force = cfg.CONF[self.name].ipa_force_ns_use
 
-    def create_zone(self, context, zone):
-        LOG.debug('Create Zone %r' % zone)
+    def create_domain(self, context, domain):
+        LOG.debug('Create Domain %r' % domain)
         ipareq = {'method': 'dnszone_add', 'id': 0}
-        params = [zone['name']]
-        servers = self.central_service.get_zone_ns_records(self.admin_context)
+        params = [domain['name']]
+        servers = self.central_service.get_domain_servers(self.admin_context)
         # just use the first one for zone creation - add the others
         # later, below - use force because designate assumes the NS
         # already exists somewhere, is resolvable, and already has
@@ -230,36 +225,36 @@ class IPABackend(base.Backend):
         args = {'idnssoamname': servers[0]['name']}
         if self.force:
             args['force'] = True
-        for dkey, ipakey in list(domain2ipa.items()):
-            if dkey in zone:
-                args[ipakey] = zone[dkey]
+        for dkey, ipakey in domain2ipa.iteritems():
+            if dkey in domain:
+                args[ipakey] = domain[dkey]
         ipareq['params'] = [params, args]
         self._call_and_handle_error(ipareq)
         # add NS records for all of the other servers
         if len(servers) > 1:
             ipareq = {'method': 'dnsrecord_add', 'id': 0}
-            params = [zone['name'], "@"]
+            params = [domain['name'], "@"]
             args = {'nsrecord': servers[1:]}
             if self.force:
                 args['force'] = True
             ipareq['params'] = [params, args]
             self._call_and_handle_error(ipareq)
 
-    def update_zone(self, context, zone):
-        LOG.debug('Update Zone %r' % zone)
+    def update_domain(self, context, domain):
+        LOG.debug('Update Domain %r' % domain)
         ipareq = {'method': 'dnszone_mod', 'id': 0}
-        params = [zone['name']]
+        params = [domain['name']]
         args = {}
-        for dkey, ipakey in list(domain2ipa.items()):
-            if dkey in zone:
-                args[ipakey] = zone[dkey]
+        for dkey, ipakey in domain2ipa.iteritems():
+            if dkey in domain:
+                args[ipakey] = domain[dkey]
         ipareq['params'] = [params, args]
         self._call_and_handle_error(ipareq)
 
-    def delete_zone(self, context, zone):
-        LOG.debug('Delete Zone %r' % zone)
+    def delete_domain(self, context, domain):
+        LOG.debug('Delete Domain %r' % domain)
         ipareq = {'method': 'dnszone_del', 'id': 0}
-        params = [zone['name']]
+        params = [domain['name']]
         args = {}
         ipareq['params'] = [params, args]
         self._call_and_handle_error(ipareq)
