@@ -13,28 +13,35 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import eventlet
+
+eventlet.monkey_patch()
+
 import os
 import socket
-from oslo.config import cfg
 
-cfg.CONF.import_opt('default_log_levels', 'designate.openstack.common.log')
-cfg.CONF.import_opt('control_exchange', 'designate.openstack.common.rpc')
-cfg.CONF.import_opt('allowed_rpc_exception_modules',
-                    'designate.openstack.common.rpc')
+from oslo.config import cfg
+from oslo_log import log
+from oslo_concurrency import lockutils
+from oslo import messaging
+
 
 cfg.CONF.register_opts([
     cfg.StrOpt('host', default=socket.gethostname(),
                help='Name of this node'),
-    cfg.StrOpt('pybasedir',
-               default=os.path.abspath(os.path.join(os.path.dirname(__file__),
-                                                    '../')),
-               help='Directory where the nova python module is installed'),
-    cfg.StrOpt('state-path', default='$pybasedir',
+    cfg.StrOpt(
+        'pybasedir',
+        default=os.path.abspath(os.path.join(os.path.dirname(__file__),
+                                             '../')),
+        help='Directory where the designate python module is installed'
+    ),
+    cfg.StrOpt('state-path', default='/var/lib/designate',
                help='Top-level directory for maintaining designate\'s state'),
 
-
     cfg.StrOpt('central-topic', default='central', help='Central Topic'),
-    cfg.StrOpt('agent-topic', default='agent', help='Agent Topic'),
+    cfg.StrOpt('mdns-topic', default='mdns', help='mDNS Topic'),
+    cfg.StrOpt('pool-manager-topic', default='pool_manager',
+               help='Pool Manager Topic'),
 
     # Default TTL
     cfg.IntOpt('default-ttl', default=3600),
@@ -47,19 +54,20 @@ cfg.CONF.register_opts([
 ])
 
 # Set some Oslo Log defaults
-cfg.CONF.set_default('default_log_levels',
-                     ['amqplib=WARN',
-                      'amqp=WARN',
-                      'sqlalchemy=WARN',
-                      'boto=WARN',
-                      'suds=INFO',
-                      'keystone=INFO',
-                      'eventlet.wsgi.server=WARN',
-                      'stevedore=WARN',
-                      'keystoneclient.middleware.auth_token=INFO'])
+log.set_defaults(default_log_levels=[
+    'amqplib=WARN',
+    'amqp=WARN',
+    'sqlalchemy=WARN',
+    'boto=WARN',
+    'suds=INFO',
+    'keystone=INFO',
+    'eventlet.wsgi.server=WARN',
+    'stevedore=WARN',
+    'keystonemiddleware.auth_token=INFO',
+    'oslo.messaging=WARN'])
 
 # Set some Oslo RPC defaults
-cfg.CONF.set_default('control_exchange', 'designate')
-cfg.CONF.set_default('allowed_rpc_exception_modules',
-                     ['designate.exceptions',
-                      'designate.openstack.common.exception'])
+messaging.set_transport_defaults('designate')
+
+# Set some Oslo Oslo Concurrency defaults
+lockutils.set_defaults(lock_path='$state_path')
