@@ -13,21 +13,21 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
+from oslo.config import cfg
 
 cfg.CONF.register_group(cfg.OptGroup(
     name='service:agent', title="Configuration for the Agent Service"
 ))
 
 OPTS = [
-    cfg.IntOpt('workers',
+    cfg.IntOpt('workers', default=None,
                help='Number of agent worker processes to spawn'),
     cfg.IntOpt('threads', default=1000,
                help='Number of agent greenthreads to spawn'),
-    cfg.IPOpt('host', default='0.0.0.0',
-              help='The Agent Bind Host'),
-    cfg.PortOpt('port', default=5358,
-                help='mDNS Port Number'),
+    cfg.StrOpt('host', default='0.0.0.0',
+               help='The Agent Bind Host'),
+    cfg.IntOpt('port', default=5358,
+               help='mDNS Port Number'),
     cfg.IntOpt('tcp-backlog', default=100,
                help='The Agent TCP Backlog'),
     cfg.FloatOpt('tcp-recv-timeout', default=0.5,
@@ -38,11 +38,8 @@ OPTS = [
                 help='List of masters for the Agent, format ip:port'),
     cfg.StrOpt('backend-driver', default='bind9',
                help='The backend driver to use'),
-    cfg.StrOpt('transfer-source',
+    cfg.StrOpt('transfer-source', default=None,
                help='An IP address to be used to fetch zones transferred in'),
-    cfg.FloatOpt('notify-delay', default=0.0,
-               help='Delay after a NOTIFY arrives for a zone that the Agent '
-               'will pause and drop subsequent NOTIFYs for that zone'),
 ]
 
 cfg.CONF.register_opts(OPTS, group='service:agent')
