@@ -13,53 +13,54 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
-"""
-    agent.handler
-    ~~~~~~~~~~~~~
-    Typically runs on the resolver hosts. Listen for incoming DNS requests
-    on a port different than 53 and execute create_zone/delete_zone on the
-    backend adaptor (e.g. Bind9)
-
-    Configured in [service:agent]
-"""
-
 import dns
-import dns.flags
-import dns.message
 import dns.opcode
 import dns.rcode
-from oslo_config import cfg
+import dns.message
+import dns.flags
+import dns.opcode
+from oslo.config import cfg
 from oslo_log import log as logging
 
-from designate.backend import agent_backend
-import designate.backend.private_codes as pcodes
-from designate import dnsutils
 from designate import utils
+from designate import dnsutils
+from designate.backend import agent_backend
+from designate.i18n import _LW
+from designate.i18n import _LI
+
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
+# Command and Control OPCODE
+CC = 14
+
+# Private DNS CLASS Uses
+ClassCC = 65280
+
+# Private RR Code Uses
+SUCCESS = 65280
+FAILURE = 65281
+CREATE = 65282
+DELETE = 65283
+
 
 class RequestHandler(object):
     def __init__(self):
         self.masters = []
         for server in CONF['service:agent'].masters:
             raw_server = utils.split_host_port(server)
-            master = {'host': raw_server[0], 'port': int(raw_server[1])}
+            master = {'ip': raw_server[0], 'port': int(raw_server[1])}
             self.masters.append(master)
 
-        LOG.info("Agent masters: %(masters)s", {'masters': self.masters})
+        LOG.info(_LI("Agent masters: %(masters)s") %
+                 {'masters': self.masters})
 
         self.allow_notify = CONF['service:agent'].allow_notify
         self.transfer_source = CONF['service:agent'].transfer_source
         backend_driver = cfg.CONF['service:agent'].backend_driver
         self.backend = agent_backend.get_backend(backend_driver, self)
 
-        # TODO(johnsom) Remove this after the agents framework is removed or
-        # the protocol has been updated to not use an unassigned opcode(14).
-        dns.opcode.Opcode = pcodes.OpcodeWith14
-
     def __call__(self, request):
         """
         :param request: DNS Request Message
@@ -71,11 +72,11 @@ class RequestHandler(object):
         opcode = request.opcode()
         if opcode == dns.opcode.NOTIFY:
             response = self._handle_notify(request)
-        elif opcode == pcodes.CC:
-            if rdclass == pcodes.CLASSCC:
-                if rdtype == pcodes.CREATE:
+        elif opcode == CC:
+            if rdclass == ClassCC:
+                if rdtype == CREATE:
                     response = self._handle_create(request)
-                elif rdtype == pcodes.DELETE:
+                elif rdtype == DELETE:
                     response = self._handle_delete(request)
                 else:
                     response = self._handle_query_error(request,
@@ -88,7 +89,7 @@ class RequestHandler(object):
 
         # TODO(Tim): Answer Type 65XXX queries
         yield response
-        return
+        raise StopIteration
 
     def _handle_query_error(self, request, rcode):
         """
@@ -107,38 +108,29 @@ class RequestHandler(object):
 
         question = request.question[0]
         requester = request.environ['addr'][0]
-        zone_name = question.name.to_text()
-        if isinstance(zone_name, bytes):
-            zone_name = zone_name.decode('utf-8')
+        domain_name = question.name.to_text()
 
-        if not self._allowed(request, requester, "CREATE", zone_name):
+        if not self._allowed(request, requester, "CREATE", domain_name):
             response.set_rcode(dns.rcode.from_text("REFUSED"))
             return response
 
-        serial = self.backend.find_zone_serial(zone_name)
+        serial = self.backend.find_domain_serial(domain_name)
 
         if serial is not None:
-            # Does this warrant a warning?
-            # There is a race condition between checking if the zone exists
-            # and creating it.
-            LOG.warning("Not creating %(name)s, zone already exists",
-                        {'name': zone_name})
+            LOG.warn(_LW("Not creating %(name)s, zone already exists") %
+                 {'name': domain_name})
             # Provide an authoritative answer
             response.flags |= dns.flags.AA
             return response
 
-        LOG.debug("Received %(verb)s for %(name)s from %(host)s",
-                  {'verb': "CREATE", 'name': zone_name, 'host': requester})
+        LOG.debug("Received %(verb)s for %(name)s from %(host)s" %
+                 {'verb': "CREATE", 'name': domain_name, 'host': requester})
 
         try:
-            # Receive an AXFR from MiniDNS to populate the zone
-            zone = dnsutils.do_axfr(zone_name, self.masters,
-                                    source=self.transfer_source)
-            self.backend.create_zone(zone)
-        except Exception as e:
-            # TODO(Federico) unknown exceptions should be logged with a full
-            # traceback. Same in the other methods.
-            LOG.error("Exception while creating zone %r", e)
+            zone = dnsutils.do_axfr(domain_name, self.masters,
+                source=self.transfer_source)
+            self.backend.create_domain(zone)
+        except Exception:
             response.set_rcode(dns.rcode.from_text("SERVFAIL"))
             return response
 
@@ -160,37 +152,35 @@ class RequestHandler(object):
 
         question = request.question[0]
         requester = request.environ['addr'][0]
-        zone_name = question.name.to_text()
-        if isinstance(zone_name, bytes):
-            zone_name = zone_name.decode('utf-8')
+        domain_name = question.name.to_text()
 
-        if not self._allowed(request, requester, "NOTIFY", zone_name):
+        if not self._allowed(request, requester, "NOTIFY", domain_name):
             response.set_rcode(dns.rcode.from_text("REFUSED"))
             return response
 
-        serial = self.backend.find_zone_serial(zone_name)
+        serial = self.backend.find_domain_serial(domain_name)
 
         if serial is None:
-            LOG.warning("Refusing NOTIFY for %(name)s, doesn't exist",
-                        {'name': zone_name})
+            LOG.warn(_LW("Refusing NOTIFY for %(name)s, doesn't exist") %
+                 {'name': domain_name})
             response.set_rcode(dns.rcode.from_text("REFUSED"))
             return response
 
-        LOG.debug("Received %(verb)s for %(name)s from %(host)s",
-                  {'verb': "NOTIFY", 'name': zone_name, 'host': requester})
+        LOG.debug("Received %(verb)s for %(name)s from %(host)s" %
+                 {'verb': "NOTIFY", 'name': domain_name, 'host': requester})
 
         # According to RFC we should query the server that sent the NOTIFY
         # TODO(Tim): Reenable this when it makes more sense
         # resolver = dns.resolver.Resolver()
         # resolver.nameservers = [requester]
         # This assumes that the Master is running on port 53
-        # soa_answer = resolver.query(zone_name, 'SOA')
+        # soa_answer = resolver.query(domain_name, 'SOA')
         # Check that the serial is < serial above
 
         try:
-            zone = dnsutils.do_axfr(zone_name, self.masters,
-                                    source=self.transfer_source)
-            self.backend.update_zone(zone)
+            zone = dnsutils.do_axfr(domain_name, self.masters,
+                source=self.transfer_source)
+            self.backend.update_domain(zone)
         except Exception:
             response.set_rcode(dns.rcode.from_text("SERVFAIL"))
             return response
@@ -213,46 +203,40 @@ class RequestHandler(object):
 
         question = request.question[0]
         requester = request.environ['addr'][0]
-        zone_name = question.name.to_text()
-        if isinstance(zone_name, bytes):
-            zone_name = zone_name.decode('utf-8')
+        domain_name = question.name.to_text()
 
-        if not self._allowed(request, requester, "DELETE", zone_name):
+        if not self._allowed(request, requester, "DELETE", domain_name):
             response.set_rcode(dns.rcode.from_text("REFUSED"))
             return response
 
-        serial = self.backend.find_zone_serial(zone_name)
+        serial = self.backend.find_domain_serial(domain_name)
 
         if serial is None:
-            LOG.warning("Not deleting %(name)s, zone doesn't exist",
-                        {'name': zone_name})
+            LOG.warn(_LW("Not deleting %(name)s, zone doesn't exist") %
+                 {'name': domain_name})
             # Provide an authoritative answer
             response.flags |= dns.flags.AA
             return response
 
-        LOG.debug("Received DELETE for %(name)s from %(host)s",
-                  {'name': zone_name, 'host': requester})
+        LOG.debug("Received DELETE for %(name)s from %(host)s" %
+                 {'name': domain_name, 'host': requester})
 
         # Provide an authoritative answer
         response.flags |= dns.flags.AA
 
         # Call into the backend to Delete
         try:
-            self.backend.delete_zone(zone_name)
+            self.backend.delete_domain(domain_name)
         except Exception:
             response.set_rcode(dns.rcode.from_text("SERVFAIL"))
             return response
 
         return response
 
-    def _allowed(self, request, requester, op, zone_name):
-        # If there are no explict notifiers specified, allow all
-        if not self.allow_notify:
-            return True
-
+    def _allowed(self, request, requester, op, domain_name):
         if requester not in self.allow_notify:
-            LOG.warning("%(verb)s for %(name)s from %(server)s refused",
-                        {'verb': op, 'name': zone_name, 'server': requester})
+            LOG.warn(_LW("%(verb)s for %(name)s from %(server)s refused") %
+            {'verb': op, 'name': domain_name, 'server': requester})
             return False
 
         return True
