@@ -13,9 +13,8 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import flask
 from oslo.config import cfg
-from designate.openstack.common import jsonutils as json
+
 
 cfg.CONF.register_group(cfg.OptGroup(
     name='service:api', title="Configuration for API Service"
@@ -23,7 +22,9 @@ cfg.CONF.register_group(cfg.OptGroup(
 
 cfg.CONF.register_opts([
     cfg.IntOpt('workers', default=None,
-               help='Number of worker processes to spawn'),
+               help='Number of api worker processes to spawn'),
+    cfg.IntOpt('threads', default=1000,
+               help='Number of api greenthreads to spawn'),
     cfg.StrOpt('api-base-uri', default='http://127.0.0.1:9001/'),
     cfg.StrOpt('api_host', default='0.0.0.0',
                help='API Host'),
@@ -31,13 +32,10 @@ cfg.CONF.register_opts([
                help='API Port Number'),
     cfg.StrOpt('api_paste_config', default='api-paste.ini',
                help='File name for the paste.deploy config for designate-api'),
-    cfg.StrOpt('auth_strategy', default='noauth',
+    cfg.StrOpt('auth_strategy', default='keystone',
                help='The strategy to use for auth. Supports noauth or '
                     'keystone'),
     cfg.BoolOpt('enable-api-v1', default=True),
     cfg.BoolOpt('enable-api-v2', default=False),
+    cfg.BoolOpt('enable-api-admin', default=False),
 ], group='service:api')
-
-
-# Allows us to serialize datetime's etc
-flask.helpers.json = json
