@@ -30,16 +30,27 @@ class QuotasView(base_view.BaseView):
     def show_basic(self, context, request, quota):
         """Basic view of a quota"""
         return {
-            "api_export_size": quota['api_export_size'],
-            "zones": quota['zones'],
-            "zone_records": quota['zone_records'],
-            "zone_recordsets": quota['zone_recordsets'],
+            "zones": quota['domains'],
+            "zone_records": quota['domain_records'],
+            "zone_recordsets": quota['domain_recordsets'],
             "recordset_records": quota['recordset_records']
         }
 
     def load(self, context, request, body):
         """Extract a "central" compatible dict from an API call"""
-        valid_keys = ('zone_records', 'zone_recordsets', 'zones',
-                      'recordset_records', 'api_export_size')
+        valid_keys = ('domain_records', 'domain_recordsets', 'domains',
+                      'recordset_records')
+
+        quota = body["quota"]
+
+        old_keys = {
+            'zones': 'domains',
+            'zone_records': 'domain_records',
+            'zone_recordsets': 'domain_recordsets',
+            'recordset_records': 'recordset_records'
+        }
+
+        for key in quota:
+            quota[old_keys[key]] = quota.pop(key)
 
         return self._load(context, request, body, valid_keys)
