@@ -1,6 +1,6 @@
 # Copyright 2012 Hewlett-Packard Development Company, L.P. All Rights Reserved.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,7 +14,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import flask
-import oslo_messaging as messaging
+from oslo import messaging
 from oslo_log import log as logging
 
 from designate import rpc
