@@ -1,6 +1,6 @@
 # Copyright 2012 Hewlett-Packard Development Company, L.P. All Rights Reserved.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -28,7 +28,7 @@ blueprint = flask.Blueprint('sync', __name__)
 def sync_domains():
     context = flask.request.environ.get('context')
 
-    central_api.sync_zones(context)
+    central_api.sync_domains(context)
 
     return flask.Response(status=200)
 
@@ -37,7 +37,7 @@ def sync_domains():
 def sync_domain(domain_id):
     context = flask.request.environ.get('context')
 
-    central_api.sync_zone(context, domain_id)
+    central_api.sync_domain(context, domain_id)
 
     return flask.Response(status=200)
 
