@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -26,6 +26,6 @@ blueprint = flask.Blueprint('touch', __name__)
 def touch_domain(domain_id):
     context = flask.request.environ.get('context')
 
-    central_api.touch_zone(context, domain_id)
+    central_api.touch_domain(context, domain_id)
 
     return flask.Response(status=200)
