@@ -14,13 +14,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import flask
-from oslo_config import cfg
+from oslo.config import cfg
 from oslo_log import log as logging
 
 from designate import exceptions
 from designate import schema
 from designate import objects
-from designate.i18n import _LI
 from designate.central import rpcapi as central_rpcapi
 
 
@@ -81,7 +80,6 @@ def create_server():
     try:
         # Update the pool
         updated_pool = central_api.update_pool(context, pool)
-        LOG.info(_LI("Updated %(pool)s"), {'pool': pool})
 
     except exceptions.DuplicatePoolAttribute:
         raise exceptions.DuplicateServer()
@@ -111,15 +109,12 @@ def get_servers():
 
     # Get the default pool
     pool = central_api.get_pool(context, default_pool_id)
-    LOG.info(_LI("Retrieved %(pool)s"), {'pool': pool})
 
     servers = objects.ServerList()
 
     for ns in pool.ns_records:
         servers.append(_pool_ns_record_to_server(ns))
 
-    LOG.info(_LI("Retrieved %(servers)s"), {'servers': servers})
-
     return flask.jsonify(servers_schema.filter({'servers': servers}))
 
 
@@ -131,7 +126,6 @@ def get_server(server_id):
 
     # Get the default pool
     pool = central_api.get_pool(context, default_pool_id)
-    LOG.info(_LI("Retrieved %(pool)s"), {'pool': pool})
 
     # Create an empty PoolNsRecord object
     nameserver = objects.PoolNsRecord()
@@ -146,8 +140,6 @@ def get_server(server_id):
     if nameserver.id != server_id:
         raise exceptions.ServerNotFound
 
-    LOG.info(_LI("Retrieved %(server)s"), {'server': nameserver})
-
     server = _pool_ns_record_to_server(nameserver)
 
     return flask.jsonify(server_schema.filter(server))
@@ -190,8 +182,7 @@ def update_server(server_id):
 
     # Now that it's been validated, add it back to the pool and persist it
     pool.ns_records.append(nameserver)
-    pool = central_api.update_pool(context, pool)
-    LOG.info(_LI("Updated %(pool)s"), {'pool': pool})
+    central_api.update_pool(context, pool)
 
     return flask.jsonify(server_schema.filter(server))
 
@@ -220,7 +211,6 @@ def delete_server(server_id):
     ns_records.pop(index)
 
     # Update the pool without the deleted server
-    pool = central_api.update_pool(context, pool)
-    LOG.info(_LI("Updated %(pool)s"), {'pool': pool})
+    central_api.update_pool(context, pool)
 
     return flask.Response(status=200)
