@@ -12,13 +12,13 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from oslo_log import log as logging
 import pecan
+from oslo_log import log as logging
 
-from designate.api.v2.controllers import rest
-from designate.objects.adapters import DesignateAdapter
-from designate.objects import Pool
 from designate import utils
+from designate.api.v2.controllers import rest
+from designate.objects import Pool
+from designate.objects.adapters import DesignateAdapter
 
 
 LOG = logging.getLogger(__name__)
@@ -34,11 +34,10 @@ class PoolsController(rest.RestController):
         request = pecan.request
         context = request.environ['context']
 
-        pool = self.central_api.get_pool(context, pool_id)
-
-        LOG.info("Retrieved %(pool)s", {'pool': pool})
-
-        return DesignateAdapter.render('API_v2', pool, request=request)
+        return DesignateAdapter.render(
+            'API_v2',
+            self.central_api.get_pool(context, pool_id),
+            request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
     def get_all(self, **params):
@@ -48,28 +47,22 @@ class PoolsController(rest.RestController):
 
         # Extract the pagination params
         marker, limit, sort_key, sort_dir = utils.get_paging_params(
-                context, params, self.SORT_KEYS)
+            params, self.SORT_KEYS)
 
         # Extract any filter params.
-        accepted_filters = ('name', )
+        accepted_filters = ('name')
         criterion = self._apply_filter_params(
             params, accepted_filters, {})
 
-        pools = self.central_api.find_pools(
-            context, criterion, marker, limit, sort_key, sort_dir)
-
-        LOG.info("Retrieved %(pools)s", {'pools': pools})
-
-        return DesignateAdapter.render('API_v2', pools, request=request)
+        return DesignateAdapter.render(
+            'API_v2',
+            self.central_api.find_pools(
+                context, criterion, marker, limit, sort_key, sort_dir),
+            request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
     def post_all(self):
         """Create a Pool"""
-
-        LOG.warning("Use of this API Method is DEPRECATED. This will have "
-                    "unforeseen side affects when used with the "
-                    "designate-manage pool commands")
-
         request = pecan.request
         response = pecan.response
         context = request.environ['context']
@@ -81,14 +74,10 @@ class PoolsController(rest.RestController):
 
         # Create the pool
         pool = self.central_api.create_pool(context, pool)
-
-        LOG.info("Created %(pool)s", {'pool': pool})
-
         pool = DesignateAdapter.render('API_v2', pool, request=request)
         response.status_int = 201
 
         response.headers['Location'] = pool['links']['self']
-
         # Prepare and return the response body
         return pool
 
@@ -97,18 +86,13 @@ class PoolsController(rest.RestController):
     @utils.validate_uuid('pool_id')
     def patch_one(self, pool_id):
         """Update the specific pool"""
-
-        LOG.warning("Use of this API Method is DEPRECATED. This will have "
-                    "unforeseen side affects when used with the "
-                    "designate-manage pool commands")
-
         request = pecan.request
         context = request.environ['context']
         body = request.body_dict
         response = pecan.response
 
         if request.content_type == 'application/json-patch+json':
-            raise NotImplementedError('json-patch not implemented')
+            raise NotImplemented('json-patch not implemented')
 
         # Fetch the existing pool
         pool = self.central_api.get_pool(context, pool_id)
@@ -119,9 +103,7 @@ class PoolsController(rest.RestController):
 
         pool = self.central_api.update_pool(context, pool)
 
-        LOG.info("Updated %(pool)s", {'pool': pool})
-
-        response.status_int = 202
+        response.status_int = 200
 
         return DesignateAdapter.render('API_v2', pool, request=request)
 
@@ -129,18 +111,11 @@ class PoolsController(rest.RestController):
     @utils.validate_uuid('pool_id')
     def delete_one(self, pool_id):
         """Delete the specific pool"""
-
-        LOG.warning("Use of this API Method is DEPRECATED. This will have "
-                    "unforeseen side affects when used with the "
-                    "designate-manage pool commands")
-
         request = pecan.request
         response = pecan.response
         context = request.environ['context']
 
-        pool = self.central_api.delete_pool(context, pool_id)
-
-        LOG.info("Deleted %(pool)s", {'pool': pool})
+        self.central_api.delete_pool(context, pool_id)
 
         response.status_int = 204
 
