@@ -25,10 +25,16 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 import inspect
+
 import pecan
 import pecan.rest
 import pecan.routing
-from designate.openstack.common import log as logging
+from oslo_log import log as logging
+
+from designate import exceptions
+from designate.central import rpcapi as central_rpcapi
+from designate.i18n import _
+
 
 LOG = logging.getLogger(__name__)
 
@@ -41,6 +47,21 @@ class RestController(pecan.rest.RestController):
     Ideally, we get these additions merged upstream.
     """
 
+    # default sort_keys.  The Controllers can override this.
+    SORT_KEYS = ['created_at', 'id']
+
+    @property
+    def central_api(self):
+        return central_rpcapi.CentralAPI.get_instance()
+
+    def _apply_filter_params(self, params, accepted_filters, criterion):
+
+        for k in accepted_filters:
+            if k in params:
+                criterion[k] = params[k].replace("*", "%")
+
+        return criterion
+
     def _handle_post(self, method, remainder):
         '''
         Routes ``POST`` actions to the appropriate controller.
@@ -50,7 +71,7 @@ class RestController(pecan.rest.RestController):
             controller = self._find_controller('post_all', 'post')
             if controller:
                 return controller, []
-            pecan.abort(404)
+            pecan.abort(405)
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
@@ -61,7 +82,7 @@ class RestController(pecan.rest.RestController):
         if controller:
             return controller, remainder
 
-        pecan.abort(404)
+        pecan.abort(405)
 
     def _handle_patch(self, method, remainder):
         '''
@@ -72,7 +93,7 @@ class RestController(pecan.rest.RestController):
             controller = self._find_controller('patch_all', 'patch')
             if controller:
                 return controller, []
-            pecan.abort(404)
+            pecan.abort(405)
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
@@ -83,7 +104,7 @@ class RestController(pecan.rest.RestController):
         if controller:
             return controller, remainder
 
-        pecan.abort(404)
+        pecan.abort(405)
 
     def _handle_put(self, method, remainder):
         '''
@@ -94,7 +115,7 @@ class RestController(pecan.rest.RestController):
             controller = self._find_controller('put_all', 'put')
             if controller:
                 return controller, []
-            pecan.abort(404)
+            pecan.abort(405)
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
@@ -105,7 +126,7 @@ class RestController(pecan.rest.RestController):
         if controller:
             return controller, remainder
 
-        pecan.abort(404)
+        pecan.abort(405)
 
     def _handle_delete(self, method, remainder):
         '''
@@ -116,7 +137,7 @@ class RestController(pecan.rest.RestController):
             controller = self._find_controller('delete_all', 'delete')
             if controller:
                 return controller, []
-            pecan.abort(404)
+            pecan.abort(405)
 
         controller = getattr(self, remainder[0], None)
         if controller and not inspect.ismethod(controller):
@@ -127,4 +148,4 @@ class RestController(pecan.rest.RestController):
         if controller:
             return controller, remainder
 
-        pecan.abort(404)
+        pecan.abort(405)
