@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,13 +13,14 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
-import pecan
 
-from designate.api.v2.controllers import rest
-from designate.objects.adapters import DesignateAdapter
-from designate.objects import TsigKey
+import pecan
+from oslo_log import log as logging
+
 from designate import utils
+from designate.api.v2.controllers import rest
+from designate.objects import TsigKey
+from designate.objects.adapters import DesignateAdapter
 
 LOG = logging.getLogger(__name__)
 
@@ -35,11 +36,10 @@ class TsigKeysController(rest.RestController):
         request = pecan.request
         context = request.environ['context']
 
-        tsigkey = self.central_api.get_tsigkey(context, tsigkey_id)
-
-        LOG.info("Retrieved %(tsigkey)s", {'tsigkey': tsigkey})
-
-        return DesignateAdapter.render('API_v2', tsigkey, request=request)
+        return DesignateAdapter.render(
+            'API_v2',
+            self.central_api.get_tsigkey(context, tsigkey_id),
+            request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
     def get_all(self, **params):
@@ -49,19 +49,18 @@ class TsigKeysController(rest.RestController):
 
         # Extract the pagination params
         marker, limit, sort_key, sort_dir = utils.get_paging_params(
-                context, params, self.SORT_KEYS)
+            params, self.SORT_KEYS)
 
         # Extract any filter params
         accepted_filters = ('name', 'algorithm', 'scope')
-
         criterion = self._apply_filter_params(
             params, accepted_filters, {})
-        tsigkeys = self.central_api.find_tsigkeys(
-            context, criterion, marker, limit, sort_key, sort_dir)
 
-        LOG.info("Retrieved %(tsigkeys)s", {'tsigkeys': tsigkeys})
-
-        return DesignateAdapter.render('API_v2', tsigkeys, request=request)
+        return DesignateAdapter.render(
+            'API_v2',
+            self.central_api.find_tsigkeys(
+                context, criterion, marker, limit, sort_key, sort_dir),
+            request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
     def post_all(self):
@@ -79,8 +78,6 @@ class TsigKeysController(rest.RestController):
         tsigkey = self.central_api.create_tsigkey(
             context, tsigkey)
 
-        LOG.info("Created %(tsigkey)s", {'tsigkey': tsigkey})
-
         tsigkey = DesignateAdapter.render('API_v2', tsigkey, request=request)
 
         response.headers['Location'] = tsigkey['links']['self']
@@ -99,7 +96,7 @@ class TsigKeysController(rest.RestController):
         response = pecan.response
 
         if request.content_type == 'application/json-patch+json':
-            raise NotImplementedError('json-patch not implemented')
+            raise NotImplemented('json-patch not implemented')
 
         # Fetch the existing tsigkey entry
         tsigkey = self.central_api.get_tsigkey(context, tsigkey_id)
@@ -112,8 +109,6 @@ class TsigKeysController(rest.RestController):
         # Update and persist the resource
         tsigkey = self.central_api.update_tsigkey(context, tsigkey)
 
-        LOG.info("Updated %(tsigkey)s", {'tsigkey': tsigkey})
-
         response.status_int = 200
 
         return DesignateAdapter.render('API_v2', tsigkey, request=request)
@@ -126,9 +121,7 @@ class TsigKeysController(rest.RestController):
         response = pecan.response
         context = request.environ['context']
 
-        tsigkey = self.central_api.delete_tsigkey(context, tsigkey_id)
-
-        LOG.info("Deleted %(tsigkey)s", {'tsigkey': tsigkey})
+        self.central_api.delete_tsigkey(context, tsigkey_id)
 
         response.status_int = 204
 
