@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,23 +13,20 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
 import pecan
+from oslo.config import cfg
 
-from designate.api.v2.controllers import rest
-from designate.api.v2.controllers.zones import nameservers
-from designate.api.v2.controllers.zones import recordsets
-from designate.api.v2.controllers.zones import sharedzones
-from designate.api.v2.controllers.zones import tasks
-import designate.conf
 from designate import exceptions
+from designate import utils
+from designate.api.v2.controllers import rest
+from designate.api.v2.controllers import recordsets
+from designate.api.v2.controllers.zones import tasks
+from designate.api.v2.controllers.zones import nameservers
 from designate import objects
 from designate.objects.adapters import DesignateAdapter
-from designate import utils
 
 
-CONF = designate.conf.CONF
-LOG = logging.getLogger(__name__)
+CONF = cfg.CONF
 
 
 class ZonesController(rest.RestController):
@@ -40,7 +37,6 @@ class ZonesController(rest.RestController):
     recordsets = recordsets.RecordSetsController()
     tasks = tasks.TasksController()
     nameservers = nameservers.NameServersController()
-    shares = sharedzones.SharedZonesController()
 
     @pecan.expose(template='json:', content_type='application/json')
     @utils.validate_uuid('zone_id')
@@ -51,11 +47,10 @@ class ZonesController(rest.RestController):
         request = pecan.request
         context = request.environ['context']
 
-        zone = self.central_api.get_zone(context, zone_id)
-
-        LOG.info('Retrieved %(zone)s', {'zone': zone})
-
-        return DesignateAdapter.render('API_v2', zone, request=request)
+        return DesignateAdapter.render(
+            'API_v2',
+            self.central_api.get_domain(context, zone_id),
+            request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
     def get_all(self, **params):
@@ -64,21 +59,19 @@ class ZonesController(rest.RestController):
         context = request.environ['context']
 
         marker, limit, sort_key, sort_dir = utils.get_paging_params(
-                context, params, self.SORT_KEYS)
+            params, self.SORT_KEYS)
 
         # Extract any filter params.
-        accepted_filters = ('name', 'type', 'email', 'status',
-                            'description', 'ttl', )
+        accepted_filters = ('name', 'email', 'status', )
 
         criterion = self._apply_filter_params(
             params, accepted_filters, {})
 
-        zones = self.central_api.find_zones(
-            context, criterion, marker, limit, sort_key, sort_dir)
-
-        LOG.info('Retrieved %(zones)s', {'zones': zones})
-
-        return DesignateAdapter.render('API_v2', zones, request=request)
+        return DesignateAdapter.render(
+            'API_v2',
+            self.central_api.find_domains(
+                context, criterion, marker, limit, sort_key, sort_dir),
+            request=request)
 
     @pecan.expose(template='json:', content_type='application/json')
     def post_all(self):
@@ -89,27 +82,32 @@ class ZonesController(rest.RestController):
 
         zone = request.body_dict
 
-        if 'type' not in zone:
-            zone['type'] = 'PRIMARY'
+        # We need to check the zone type before validating the schema since if
+        # it's the type is SECONDARY we need to set the email to the mgmt email
+
+        if isinstance(zone, dict):
+            if 'type' not in zone:
+                zone['type'] = 'PRIMARY'
+
+            if zone['type'] == 'SECONDARY':
+                mgmt_email = CONF['service:central'].managed_resource_email
+                zone['email'] = mgmt_email
+
+        zone = DesignateAdapter.parse('API_v2', zone, objects.Domain())
 
-        zone = DesignateAdapter.parse('API_v2', zone, objects.Zone())
         zone.validate()
 
-        if zone.type == 'SECONDARY':
-            mgmt_email = CONF['service:central'].managed_resource_email
-            zone['email'] = mgmt_email
+        # # TODO(ekarlso): Fix this once setter or so works.
+        # masters = values.pop('masters', [])
+        # zone = objects.Domain.from_dict(values)
+        # zone.set_masters(masters)
 
         # Create the zone
-        zone = self.central_api.create_zone(context, zone)
-
-        # Shared is a virtual database column, so inject False here as a
-        # new zone cannot yet be shared.
-        zone.shared = False
-
-        LOG.info('Created %(zone)s', {'zone': zone})
+        zone = self.central_api.create_domain(context, zone)
 
         # Prepare the response headers
         # If the zone has been created asynchronously
+
         if zone['status'] == 'PENDING':
             response.status_int = 202
         else:
@@ -136,10 +134,10 @@ class ZonesController(rest.RestController):
         # TODO(kiall): Validate we have a sane UUID for zone_id
 
         # Fetch the existing zone
-        zone = self.central_api.get_zone(context, zone_id)
+        zone = self.central_api.get_domain(context, zone_id)
 
         # Don't allow updates to zones that are being deleted
-        if zone.action == 'DELETE':
+        if zone.action == "DELETE":
             raise exceptions.BadRequest('Can not update a deleting zone')
 
         if request.content_type == 'application/json-patch+json':
@@ -155,7 +153,7 @@ class ZonesController(rest.RestController):
             # 1) "Nested" resources? records inside a recordset.
             # 2) What to do when a zone doesn't exist in the first place?
             # 3) ...?
-            raise NotImplementedError('json-patch not implemented')
+            raise NotImplemented('json-patch not implemented')
         else:
             # Update the zone object with the new values
             zone = DesignateAdapter.parse('API_v2', body, zone)
@@ -168,11 +166,13 @@ class ZonesController(rest.RestController):
 
             # Update and persist the resource
 
-            increment_serial = zone.type == 'PRIMARY'
-            zone = self.central_api.update_zone(
-                context, zone, increment_serial=increment_serial)
+            if zone.type == 'SECONDARY' and 'email' in zone.obj_what_changed():
+                msg = "Changed email is not allowed."
+                raise exceptions.InvalidObject(msg)
 
-        LOG.info('Updated %(zone)s', {'zone': zone})
+            increment_serial = zone.type == 'PRIMARY'
+            zone = self.central_api.update_domain(
+                context, zone, increment_serial=increment_serial)
 
         if zone.status == 'PENDING':
             response.status_int = 202
@@ -189,9 +189,7 @@ class ZonesController(rest.RestController):
         response = pecan.response
         context = request.environ['context']
 
-        zone = self.central_api.delete_zone(context, zone_id)
+        zone = self.central_api.delete_domain(context, zone_id)
         response.status_int = 202
 
-        LOG.info('Deleted %(zone)s', {'zone': zone})
-
         return DesignateAdapter.render('API_v2', zone, request=request)
