@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,20 +13,19 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
 import pecan
+from oslo.config import cfg
 
 from designate.api.v2.controllers import rest
 from designate.objects.adapters import DesignateAdapter
-from designate import utils
 
-LOG = logging.getLogger(__name__)
+
+CONF = cfg.CONF
 
 
 class NameServersController(rest.RestController):
 
     @pecan.expose(template='json:', content_type='application/json')
-    @utils.validate_uuid("zone_id")
     def get_all(self, zone_id):
         """List NameServers for Zone"""
         request = pecan.request
@@ -35,12 +34,8 @@ class NameServersController(rest.RestController):
         # This is a work around to overcome the fact that pool ns_records list
         # object have 2 different representations in the v2 API
 
-        ns_records = self.central_api.get_zone_ns_records(context, zone_id)
-
-        LOG.info("Created %(ns_records)s", {'ns_records': ns_records})
-
         return {
             "nameservers": DesignateAdapter.render(
                 'API_v2',
-                ns_records,
+                self.central_api.get_domain_servers(context, zone_id),
                 request=request)}
