@@ -1,6 +1,6 @@
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Author: Graham Hayes <graham.hayes@hpe.com>
+# Author: Graham Hayes <graham.hayes@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,15 +13,13 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
 import pecan
+from oslo_log import log as logging
 
-from designate.api.v2.controllers import rest
-from designate import exceptions
-from designate.objects.adapters import DesignateAdapter
-from designate.objects import ZoneTransferRequest
 from designate import utils
-
+from designate.api.v2.controllers import rest
+from designate.objects import ZoneTransferRequest
+from designate.objects.adapters import DesignateAdapter
 LOG = logging.getLogger(__name__)
 
 
@@ -30,22 +28,17 @@ class TransferRequestsController(rest.RestController):
     SORT_KEYS = ['created_at', 'id', 'updated_at']
 
     @pecan.expose(template='json:', content_type='application/json')
-    @utils.validate_uuid('zone_transfer_request_id')
-    def get_one(self, zone_transfer_request_id):
+    @utils.validate_uuid('transfer_request_id')
+    def get_one(self, transfer_request_id):
         """Get transfer_request"""
 
         request = pecan.request
         context = request.environ['context']
 
-        transfer_request = self.central_api.get_zone_transfer_request(
-            context, zone_transfer_request_id)
-
-        LOG.info("Retrieved %(transfer_request)s",
-                 {'transfer_request': transfer_request})
-
         return DesignateAdapter.render(
             'API_v2',
-            transfer_request,
+            self.central_api.get_zone_transfer_request(
+                context, transfer_request_id),
             request=request,
             context=context)
 
@@ -57,20 +50,15 @@ class TransferRequestsController(rest.RestController):
 
         # Extract the pagination params
         marker, limit, sort_key, sort_dir = utils.get_paging_params(
-                context, params, self.SORT_KEYS)
+            params, self.SORT_KEYS)
 
         # Extract any filter params.
         criterion = self._apply_filter_params(params, ('status',), {})
 
-        zone_transfer_requests = self.central_api.find_zone_transfer_requests(
-            context, criterion, marker, limit, sort_key, sort_dir)
-
-        LOG.info("Retrieved %(zone_transfer_requests)s",
-                 {'zone_transfer_requests': zone_transfer_requests})
-
         return DesignateAdapter.render(
             'API_v2',
-            zone_transfer_requests,
+            self.central_api.find_zone_transfer_requests(
+                context, criterion, marker, limit, sort_key, sort_dir),
             request=request,
             context=context)
 
@@ -83,11 +71,13 @@ class TransferRequestsController(rest.RestController):
         context = request.environ['context']
         try:
             body = request.body_dict
-        except exceptions.EmptyRequestBody:
-            body = dict()
+        except Exception as e:
+            if e.message != 'TODO: Unsupported Content Type':
+                raise
+            else:
+                # Got a blank body
+                body = dict()
 
-        zone = self.central_api.get_zone(context, zone_id)
-        body['zone_name'] = zone.name
         body['zone_id'] = zone_id
 
         zone_transfer_request = DesignateAdapter.parse(
@@ -100,9 +90,6 @@ class TransferRequestsController(rest.RestController):
             context, zone_transfer_request)
         response.status_int = 201
 
-        LOG.info("Created %(zone_transfer_request)s",
-                 {'zone_transfer_request': zone_transfer_request})
-
         zone_transfer_request = DesignateAdapter.render(
             'API_v2', zone_transfer_request, request=request, context=context)
 
@@ -121,7 +108,7 @@ class TransferRequestsController(rest.RestController):
         response = pecan.response
 
         if request.content_type == 'application/json-patch+json':
-            raise NotImplementedError('json-patch not implemented')
+            raise NotImplemented('json-patch not implemented')
 
         # Fetch the existing zone_transfer_request
         zone_transfer_request = self.central_api.get_zone_transfer_request(
@@ -135,9 +122,6 @@ class TransferRequestsController(rest.RestController):
         zone_transfer_request = self.central_api.update_zone_transfer_request(
             context, zone_transfer_request)
 
-        LOG.info("Updated %(zt_request)s",
-                 {'zt_request': zone_transfer_request})
-
         response.status_int = 200
 
         return DesignateAdapter.render(
@@ -151,13 +135,10 @@ class TransferRequestsController(rest.RestController):
         response = pecan.response
         context = request.environ['context']
 
-        zone_transfer_request = self.central_api.delete_zone_transfer_request(
+        self.central_api.delete_zone_transfer_request(
             context, zone_transfer_request_id)
 
         response.status_int = 204
 
-        LOG.info("Deleted %(zone_transfer_request)s",
-                 {'zone_transfer_request': zone_transfer_request})
-
         # NOTE: This is a hack and a half.. But Pecan needs it.
         return ''
