@@ -1,6 +1,6 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hpe.com>
+# Author: Endre Karlson <endre.karlson@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,13 +13,10 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_log import log as logging
 import pecan
 
-from designate.api.v2.controllers import rest
 from designate import utils
-
-LOG = logging.getLogger(__name__)
+from designate.api.v2.controllers import rest
 
 
 class XfrController(rest.RestController):
@@ -32,11 +29,7 @@ class XfrController(rest.RestController):
         response = pecan.response
         context = request.environ['context']
 
-        zone = self.central_api.get_zone(context, zone_id)
-
-        LOG.info("Triggered XFR for %(zone)s", {'zone': zone})
-
-        self.central_api.xfr_zone(context, zone_id)
+        self.central_api.perform_zone_xfr(context, zone_id)
         response.status_int = 202
 
         # NOTE: This is a hack and a half.. But Pecan needs it.
