@@ -13,8 +13,14 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from inspect import ismethod
+from inspect import getargspec
+
+from oslo.serialization import jsonutils
 import pecan.core
-from designate.openstack.common import jsonutils
+
+from designate import exceptions
+
 
 JSON_TYPES = ('application/json', 'application/json-patch+json')
 
@@ -30,9 +36,17 @@ class Request(pecan.core.Request):
         is not hardcoded to call pecans "request.json()" method.
         """
         if self.content_type in JSON_TYPES:
-            return jsonutils.load(self.body_file)
+            try:
+                return jsonutils.load(self.body_file)
+            except ValueError as valueError:
+                raise exceptions.InvalidJson(valueError.message)
         else:
-            raise Exception('TODO: Unsupported Content Type')
+            raise exceptions.UnsupportedContentType(
+                'Content-type must be application/json')
 
-
-pecan.core.Request = Request
+__init__ = pecan.core.Pecan.__base__.__init__
+if not ismethod(__init__) or 'request_cls' not in getargspec(__init__).args:
+    # only attempt to monkey patch `pecan.Request` in older versions of pecan;
+    # newer versions support specifying a custom request implementation in the
+    # `pecan.core.Pecan` constructor via the `request_cls` argument
+    pecan.core.Request = Request
