@@ -15,66 +15,73 @@
 # under the License.
 import abc
 
-from oslo_config import cfg
+from oslo.config import cfg
 from oslo_log import log as logging
 
+from designate.i18n import _LI
 from designate.context import DesignateContext
 from designate.plugin import DriverPlugin
 
+
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
+CONF.import_opt('pool_id', 'designate.pool_manager',
+                group='service:pool_manager')
+
 
 class Backend(DriverPlugin):
     """Base class for backend implementations"""
     __plugin_type__ = 'backend'
     __plugin_ns__ = 'designate.backend'
 
-    __backend_status__ = 'untested'
-
     def __init__(self, target):
         super(Backend, self).__init__()
 
         self.target = target
         self.options = target.options
         self.masters = target.masters
-        self.host = self.options.get('host', '127.0.0.1')
-        self.port = int(self.options.get('port', 53))
 
-        # TODO(kiall): Context's should never be shared across requests.
+        # TODO(kiall): Context's should never be shared accross requests.
         self.admin_context = DesignateContext.get_admin_context()
         self.admin_context.all_tenants = True
 
-        # Options for sending NOTIFYs
-        self.timeout = CONF['service:worker'].poll_timeout
-        self.retry_interval = CONF['service:worker'].poll_retry_interval
-        self.max_retries = CONF['service:worker'].poll_max_retries
-        self.delay = CONF['service:worker'].poll_delay
+    def start(self):
+        LOG.info(_LI('Starting %s backend'), self.get_canonical_name())
+
+    def stop(self):
+        LOG.info(_LI('Stopped %s backend'), self.get_canonical_name())
 
     # Core Backend Interface
     @abc.abstractmethod
-    def create_zone(self, context, zone):
+    def create_domain(self, context, domain):
         """
-        Create a DNS zone.
+        Create a DNS domain.
 
         :param context: Security context information.
-        :param zone: the DNS zone.
+        :param domain: the DNS domain.
         """
 
-    def update_zone(self, context, zone):
+    def update_domain(self, context, domain):
         """
-        Update a DNS zone.
+        Update a DNS domain.
 
         :param context: Security context information.
-        :param zone: the DNS zone.
+        :param domain: the DNS domain.
         """
-        LOG.debug('Update Zone')
 
     @abc.abstractmethod
-    def delete_zone(self, context, zone, zone_params):
+    def delete_domain(self, context, domain):
         """
-        Delete a DNS zone.
+        Delete a DNS domain.
 
         :param context: Security context information.
-        :param zone: the DNS zone.
+        :param domain: the DNS domain.
         """
+
+    def ping(self, context):
+        """Ping the Backend service"""
+
+        return {
+            'status': None
+        }
