@@ -1,6 +1,6 @@
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hpe.com>
+# Author: Endre Karlson <endre.karlson@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,27 +13,30 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import json
 import time
 
+from eventlet import Timeout
+from oslo.config import cfg
 from oslo_log import log as logging
-from oslo_serialization import jsonutils
 import requests
 from requests.adapters import HTTPAdapter
 
-from designate.backend import base
-import designate.conf
 from designate import exceptions
 from designate import utils
+from designate.backend import base
+from designate.i18n import _LI
+from designate.i18n import _LW
+
 
-CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
-CFG_GROUP_NAME = 'backend:dynect'
+CONF = cfg.CONF
+CFG_GROUP = 'backend:dynect'
 
 
 class DynClientError(exceptions.Backend):
     """The base exception class for all HTTP exceptions.
     """
-
     def __init__(self, data=None, job_id=None, msgs=None,
                  http_status=None, url=None, method=None, details=None):
         self.data = data
@@ -44,13 +47,14 @@ class DynClientError(exceptions.Backend):
         self.url = url
         self.method = method
         self.details = details
-        formatted_string = (
-            f'{self.msgs} (HTTP {self.method} to {self.url} - '
-            f'{self.http_status}) - {self.details}'
-        )
+        formatted_string = "%s (HTTP %s to %s - %s) - %s" % (self.msgs,
+                                                             self.method,
+                                                             self.url,
+                                                             self.http_status,
+                                                             self.details)
         if job_id:
-            formatted_string += f' (Job-ID: {job_id})'
-        super().__init__(formatted_string)
+            formatted_string += " (Job-ID: %s)" % job_id
+        super(DynClientError, self).__init__(formatted_string)
 
     @staticmethod
     def from_response(response, details=None):
@@ -89,21 +93,22 @@ class DynClientOperationBlocked(exceptions.BadRequest, DynClientError):
     error_type = 'operation_blocked'
 
 
-class DynClient:
+class DynClient(object):
     """
     DynECT service client.
 
     https://help.dynect.net/rest/
     """
-
-    def __init__(self, customer_name, user_name, password, timeout, timings,
-                 verify=True, retries=1, pool_maxsize=10, pool_connections=10):
-        self.endpoint = 'https://api.dynect.net:443'
-        self.api_version = '3.5.6'
-
+    def __init__(self, customer_name, user_name, password,
+                 endpoint="https://api.dynect.net:443",
+                 api_version='3.5.6', headers=None, verify=True, retries=1,
+                 timeout=10, timings=False, pool_maxsize=10,
+                 pool_connections=10):
         self.customer_name = customer_name
         self.user_name = user_name
         self.password = password
+        self.endpoint = endpoint
+        self.api_version = api_version
 
         self.times = []  # [("item", starttime, endtime), ...]
         self.timings = timings
@@ -118,17 +123,17 @@ class DynClient:
         session.headers = {
             'Content-Type': 'application/json',
             'Accept': 'application/json',
-            'API-Version': self.api_version,
-            'User-Agent': 'DynECTClient'
-        }
+            'API-Version': api_version,
+            'User-Agent': 'DynECTClient'}
 
-        adapter = HTTPAdapter(
-            max_retries=int(retries),
-            pool_maxsize=int(pool_maxsize),
-            pool_connections=int(pool_connections),
-            pool_block=True
-        )
-        session.mount(self.endpoint, adapter)
+        if headers is not None:
+            session.headers.update(headers)
+
+        adapter = HTTPAdapter(max_retries=int(retries),
+                              pool_maxsize=int(pool_maxsize),
+                              pool_connections=int(pool_connections),
+                              pool_block=True)
+        session.mount(endpoint, adapter)
         self.http = session
 
     def _http_log_req(self, method, url, kwargs):
@@ -139,15 +144,28 @@ class DynClient:
         ]
 
         for element in kwargs['headers']:
-            header = "-H '{}: {}'".format(element, kwargs['headers'][element])
+            header = "-H '%s: %s'" % (element, kwargs['headers'][element])
             string_parts.append(header)
 
-        LOG.debug('REQ: %s', ' '.join(string_parts))
+        LOG.debug("REQ: %s" % " ".join(string_parts))
         if 'data' in kwargs:
-            LOG.debug('REQ BODY: %s\n', kwargs['data'])
+            LOG.debug("REQ BODY: %s\n" % (kwargs['data']))
 
     def _http_log_resp(self, resp):
-        LOG.debug('RESP: [%s] %s\n', resp.status_code, resp.headers)
+        LOG.debug(
+            "RESP: [%s] %s\n" %
+            (resp.status_code,
+             resp.headers))
+        if resp._content_consumed:
+            LOG.debug(
+                "RESP BODY: %s\n" %
+                resp.text)
+
+    def get_timings(self):
+        return self.times
+
+    def reset_timings(self):
+        self.times = []
 
     def _request(self, method, url, **kwargs):
         """
@@ -182,22 +200,48 @@ class DynClient:
             self._http_log_req(method, url, kwargs)
 
             # NOTE: Set it back to the original data and serialize it.
-            kwargs['data'] = jsonutils.dump_as_bytes(data)
+            kwargs['data'] = json.dumps(data)
         else:
             self._http_log_req(method, url, kwargs)
 
-        start_time = time.monotonic()
+        if self.timings:
+            start_time = time.time()
         resp = self.http.request(method, url, **kwargs)
         if self.timings:
-            self.times.append((f"{method} {url}",
-                               start_time, time.monotonic()))
+            self.times.append(("%s %s" % (method, url),
+                               start_time, time.time()))
         self._http_log_resp(resp)
 
         if resp.status_code >= 400:
-            LOG.debug('Request returned failure status: %s', resp.status_code)
+            LOG.debug(
+                "Request returned failure status: %s" %
+                resp.status_code)
             raise DynClientError.from_response(resp)
         return resp
 
+    def poll_response(self, response):
+        """
+        The API might return a job nr in the response in case of a async
+        response: https://github.com/fog/fog/issues/575
+        """
+        status = response.status
+
+        timeout = Timeout(CONF[CFG_GROUP].job_timeout)
+        try:
+            while status == 307:
+                time.sleep(1)
+                url = response.headers.get('Location')
+                LOG.debug("Polling %s" % url)
+
+                polled_response = self.get(url)
+                status = response.status
+        except Timeout as t:
+            if t == timeout:
+                raise DynTimeoutError('Timeout reached when pulling job.')
+        finally:
+            timeout.cancel()
+        return polled_response
+
     def request(self, method, url, retries=2, **kwargs):
         if self.token is None and not self.authing:
             self.login()
@@ -212,6 +256,9 @@ class DynClient:
             else:
                 raise
 
+        if response.status_code == 307:
+            response = self.poll_response(response)
+
         return response.json()
 
     def login(self):
@@ -233,10 +280,18 @@ class DynClient:
         response = self.request('POST', *args, **kwargs)
         return response
 
+    def get(self, *args, **kwargs):
+        response = self.request('GET', *args, **kwargs)
+        return response
+
     def put(self, *args, **kwargs):
         response = self.request('PUT', *args, **kwargs)
         return response
 
+    def patch(self, *args, **kwargs):
+        response = self.request('PATCH', *args, **kwargs)
+        return response
+
     def delete(self, *args, **kwargs):
         response = self.request('DELETE', *args, **kwargs)
         return response
@@ -248,10 +303,25 @@ class DynECTBackend(base.Backend):
     """
     __plugin_name__ = 'dynect'
 
-    __backend_status__ = 'untested'
+    @classmethod
+    def get_cfg_opts(cls):
+        group = cfg.OptGroup(
+            name=CFG_GROUP, title='Backend options for DynECT'
+        )
+
+        opts = [
+            cfg.IntOpt('job_timeout', default=30,
+                       help="Timeout in seconds for pulling a job in DynECT."),
+            cfg.IntOpt('timeout', help="Timeout in seconds for API Requests.",
+                       default=10),
+            cfg.BoolOpt('timings', help="Measure requests timings.",
+                        default=False),
+        ]
+
+        return [(group, opts)]
 
     def __init__(self, target):
-        super().__init__(target)
+        super(DynECTBackend, self).__init__(target)
 
         self.customer_name = self.options.get('customer_name')
         self.username = self.options.get('username')
@@ -269,19 +339,14 @@ class DynECTBackend(base.Backend):
             customer_name=self.customer_name,
             user_name=self.username,
             password=self.password,
-            timeout=CONF[CFG_GROUP_NAME].timeout,
-            timings=CONF[CFG_GROUP_NAME].timings)
+            timeout=CONF[CFG_GROUP].timeout,
+            timings=CONF[CFG_GROUP].timings)
 
-    def create_zone(self, context, zone):
-        LOG.info(
-            'Creating zone %(d_id)s / %(d_name)s',
-            {
-                'd_id': zone['id'],
-                'd_name': zone['name']
-            }
-        )
+    def create_domain(self, context, domain):
+        LOG.info(_LI('Creating domain %(d_id)s / %(d_name)s') %
+                 {'d_id': domain['id'], 'd_name': domain['name']})
 
-        url = '/Secondary/%s' % zone['name'].rstrip('.')
+        url = '/Secondary/%s' % domain['name'].rstrip('.')
         data = {
             'masters': [m.host for m in self.masters]
         }
@@ -299,39 +364,51 @@ class DynECTBackend(base.Backend):
         except DynClientError as e:
             for emsg in e.msgs:
                 if emsg['ERR_CD'] == 'TARGET_EXISTS':
-                    LOG.info(
-                        'Zone already exists, updating existing zone '
-                        'instead %s', zone['name']
-                    )
+                    msg = _LI("Domain already exists, updating existing "
+                              "domain instead %s")
+                    LOG.info(msg % domain['name'])
                     client.put(url, data=data)
                     break
             else:
-                raise
+                raise e
 
         client.put(url, data={'activate': True})
         client.logout()
 
-    def delete_zone(self, context, zone, zone_params=None):
-        LOG.info(
-            'Deleting zone %(d_id)s / %(d_name)s', {
-                'd_id': zone['id'],
-                'd_name': zone['name']
-            }
-        )
-        url = '/Zone/%s' % zone['name'].rstrip('.')
+    def update_domain(self, context, domain):
+        LOG.debug('Discarding update_domain call, not-applicable')
+
+    def delete_domain(self, context, domain):
+        LOG.info(_LI('Deleting domain %(d_id)s / %(d_name)s') %
+                 {'d_id': domain['id'], 'd_name': domain['name']})
+        url = '/Zone/%s' % domain['name'].rstrip('.')
         client = self.get_client()
         try:
             client.delete(url)
         except DynClientError as e:
             if e.http_status == 404:
-                LOG.warning(
-                    'Attempt to delete %(d_id)s / %(d_name)s caused 404, '
-                    'ignoring.', {
-                        'd_id': zone['id'],
-                        'd_name': zone['name']
-                    }
-                )
+                LOG.warn(_LW("Attempt to delete %(d_id)s / %(d_name)s "
+                             "caused 404, ignoring.") %
+                         {'d_id': domain['id'], 'd_name': domain['name']})
                 pass
             else:
                 raise
         client.logout()
+
+    def create_recordset(self, context, domain, recordset):
+        LOG.debug('Discarding create_recordset call, not-applicable')
+
+    def update_recordset(self, context, domain, recordset):
+        LOG.debug('Discarding update_recordset call, not-applicable')
+
+    def delete_recordset(self, context, domain, recordset):
+        LOG.debug('Discarding delete_recordset call, not-applicable')
+
+    def create_record(self, context, domain, recordset, record):
+        LOG.debug('Discarding create_record call, not-applicable')
+
+    def update_record(self, context, domain, recordset, record):
+        LOG.debug('Discarding update_record call, not-applicable')
+
+    def delete_record(self, context, domain, recordset, record):
+        LOG.debug('Discarding delete_record call, not-applicable')
