@@ -1,3 +1,4 @@
+# flake8: noqa
 # Copyright 2012 Managed I.T.
 #
 # Author: Kiall Mac Innes <kiall@managedit.ie>
@@ -16,6 +17,8 @@
 from oslo_log import log as logging
 from sqlalchemy import MetaData, Table, Column, Boolean
 
+from designate.i18n import _LW
+
 
 LOG = logging.getLogger(__name__)
 meta = MetaData()
@@ -34,13 +37,13 @@ def upgrade(migrate_engine):
     # join from powerdns.records -> powerdns.domains -> designate.domains, so
     # we can't perform the second half here.
     query = records_table.update().values(inherit_ttl=False)
-    query = query.where(records_table.c.ttl is not None)
+    query = query.where(records_table.c.ttl != None)
     query.execute()
 
     # If there are records without an explicity configured TTL, we'll need
     # a manual post-migration step.
     query = records_table.select()
-    query = query.where(records_table.c.ttl is None)
+    query = query.where(records_table.c.ttl == None)
     c = query.count()
 
     if c > 0:
@@ -50,8 +53,8 @@ def upgrade(migrate_engine):
                'dns.records.ttl = designate.domains.ttl WHERE powerdns.records'
                '.inherit_ttl = 1;')
 
-        LOG.warning('**** A manual post-migration step is required ****')
-        LOG.warning('Please issue this query: %s', pmq)
+        LOG.warn(_LW('**** A manual post-migration step is required ****'))
+        LOG.warn(_LW('Please issue this query: %s' % pmq))
 
 
 def downgrade(migrate_engine):
