@@ -1,6 +1,6 @@
 # Copyright 2012-2014 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -15,7 +15,7 @@
 # under the License.
 from sqlalchemy import MetaData, Table, Column, String, Integer
 
-from oslo_config import cfg
+from oslo.config import cfg
 
 from designate.sqlalchemy.types import UUID
 
@@ -28,12 +28,12 @@ domains = Table(
     'domains', metadata,
     Column('id', Integer, primary_key=True, autoincrement=True),
 
-    Column('designate_id', UUID, nullable=False),
+    Column('designate_id', UUID(), nullable=False),
     Column('name', String(255), nullable=False, unique=True),
     Column('master', String(255), nullable=True),
-    Column('last_check', Integer, default=None, nullable=True),
+    Column('last_check', Integer(), default=None, nullable=True),
     Column('type', String(6), nullable=False),
-    Column('notified_serial', Integer, default=None, nullable=True),
+    Column('notified_serial', Integer(), default=None, nullable=True),
     Column('account', String(40), default=None, nullable=True),
     mysql_engine='InnoDB',
     mysql_charset='utf8')
