@@ -1,6 +1,6 @@
-# Copyright 2013 Hewlett-Packard Development Company, L.P.
+# Copyright 2014 Rackspace Inc.
 #
-# Author: Kiall Mac Innes <kiall@hp.com>
+# Author: Tim Simmons <tim.simmons@rackspace.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -16,8 +16,8 @@
 import sys
 
 from oslo.config import cfg
+from oslo_log import log as logging
 
-from designate.openstack.common import log as logging
 from designate import service
 from designate import utils
 from designate.agent import service as agent_service
@@ -25,13 +25,14 @@ from designate.agent import service as agent_service
 
 CONF = cfg.CONF
 CONF.import_opt('workers', 'designate.agent', group='service:agent')
+CONF.import_opt('threads', 'designate.agent', group='service:agent')
 
 
 def main():
     utils.read_config('designate', sys.argv)
-    logging.setup('designate')
+    logging.setup(CONF, 'designate')
+    utils.setup_gmr(log_dir=cfg.CONF.log_dir)
 
-    server = agent_service.Service.create(
-        binary='designate-agent')
+    server = agent_service.Service(threads=CONF['service:agent'].threads)
     service.serve(server, workers=CONF['service:agent'].workers)
     service.wait()
