@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -15,30 +15,24 @@
 # under the License.
 import sys
 
+from oslo.config import cfg
 from oslo_log import log as logging
-from oslo_reports import guru_meditation_report as gmr
-from oslo_reports import opts as gmr_opts
 
-from designate.api import service as api_service
-import designate.conf
-from designate import heartbeat_emitter
-from designate import service
+from designate.openstack.common import service
 from designate import utils
-from designate import version
+from designate.api import service as api_service
 
 
-CONF = designate.conf.CONF
-CONF.import_group('keystone_authtoken', 'keystonemiddleware.auth_token')
+CONF = cfg.CONF
+CONF.import_opt('workers', 'designate.api', group='service:api')
+CONF.import_opt('threads', 'designate.api', group='service:api')
 
 
 def main():
     utils.read_config('designate', sys.argv)
     logging.setup(CONF, 'designate')
-    gmr_opts.set_defaults(CONF)
-    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
+    utils.setup_gmr(log_dir=cfg.CONF.log_dir)
 
-    server = api_service.Service()
-    heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
-    service.serve(server, workers=CONF['service:api'].workers)
-    heartbeat.start()
-    service.wait()
+    server = api_service.Service(threads=CONF['service:api'].threads)
+    launcher = service.launch(server, CONF['service:api'].workers)
+    launcher.wait()
