@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -15,28 +15,24 @@
 # under the License.
 import sys
 
+from oslo.config import cfg
 from oslo_log import log as logging
-from oslo_reports import guru_meditation_report as gmr
 
-from designate.central import service as central_service
-import designate.conf
-from designate import heartbeat_emitter
 from designate import service
 from designate import utils
-from designate import version
+from designate.central import service as central
 
 
-CONF = designate.conf.CONF
+CONF = cfg.CONF
+CONF.import_opt('workers', 'designate.central', group='service:central')
+CONF.import_opt('threads', 'designate.central', group='service:central')
 
 
 def main():
     utils.read_config('designate', sys.argv)
     logging.setup(CONF, 'designate')
-    gmr.TextGuruMeditation.setup_autorun(version)
+    utils.setup_gmr(log_dir=cfg.CONF.log_dir)
 
-    server = central_service.Service()
-    heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name,
-                                                        rpc_api=server)
+    server = central.Service(threads=CONF['service:central'].threads)
     service.serve(server, workers=CONF['service:central'].workers)
-    heartbeat.start()
     service.wait()
