@@ -15,29 +15,21 @@
 # under the License.
 #
 # Copied: designate
-
+import os
 import sys
-import traceback
 
 import eventlet
-from oslo_config import cfg
+from oslo.config import cfg
 from oslo_log import log as logging
-from oslo_reports import guru_meditation_report as gmr
 from stevedore.extension import ExtensionManager
 
-import designate.conf
 from designate import utils
-from designate import version
+from designate.i18n import _
 
 eventlet.monkey_patch(os=False)
-# Monkey patch the original current_thread to use the up-to-date _active
-# global variable. See https://bugs.launchpad.net/bugs/1863021 and
-# https://github.com/eventlet/eventlet/issues/592
-import __original_module_threading as orig_threading  # noqa
-import threading  # noqa
-orig_threading.current_thread.__globals__['_active'] = threading._active
 
-CONF = designate.conf.CONF
+
+CONF = cfg.CONF
 
 
 def methods_of(obj):
@@ -53,7 +45,7 @@ def methods_of(obj):
 
 def get_available_commands():
     em = ExtensionManager('designate.manage')
-    return {e.name: e.plugin for e in em.extensions}
+    return dict([(e.name, e.plugin) for e in em.extensions])
 
 
 def add_command_parsers(subparsers):
@@ -64,9 +56,8 @@ def add_command_parsers(subparsers):
         parser.set_defaults(command_object=command_object)
 
         category_subparsers = parser.add_subparsers(dest='action')
-        category_subparsers.required = True
 
-        for action, action_fn in methods_of(command_object):
+        for (action, action_fn) in methods_of(command_object):
             action = getattr(action_fn, '_cmd_name', action)
             parser = category_subparsers.add_parser(action)
 
@@ -78,8 +69,8 @@ def add_command_parsers(subparsers):
             parser.set_defaults(action_kwargs=action_kwargs)
 
 
-category_opt = cfg.SubCommandOpt('category', title='Commands',
-                                 help='Available Commands',
+category_opt = cfg.SubCommandOpt('category', title="Commands",
+                                 help="Available Commands",
                                  handler=add_command_parsers)
 
 
@@ -93,11 +84,11 @@ def get_arg_string(args):
             # This is long optional arg
             arg = args[2:]
         else:
-            arg = args[1:]
+            arg = args[3:]
     else:
         arg = args
 
-    return arg.replace('-', '_')
+    return arg
 
 
 def fetch_func_args(func):
@@ -111,15 +102,25 @@ def fetch_func_args(func):
 
 def main():
     CONF.register_cli_opt(category_opt)
-    utils.read_config('designate', sys.argv)
-    logging.setup(CONF, 'designate')
-
-    gmr.TextGuruMeditation.setup_autorun(version)
 
     try:
-        fn = CONF.category.action_fn
-        fn_args = fetch_func_args(fn)
-        fn(*fn_args)
-    except Exception:
-        print('An error has occurred:\n%s' % traceback.format_exc())
-        return 255
+        utils.read_config('designate', sys.argv)
+        logging.setup(CONF, 'designate')
+    except cfg.ConfigFilesNotFoundError:
+        cfgfile = CONF.config_file[-1] if CONF.config_file else None
+        if cfgfile and not os.access(cfgfile, os.R_OK):
+            st = os.stat(cfgfile)
+            print(_("Could not read %s. Re-running with sudo") % cfgfile)
+            try:
+                os.execvp('sudo', ['sudo', '-u', '#%s' % st.st_uid] + sys.argv)
+            except Exception:
+                print(_('sudo failed, continuing as if nothing happened'))
+
+        print(_('Please re-run designate-manage as root.'))
+        sys.exit(2)
+
+    utils.setup_gmr(log_dir=cfg.CONF.log_dir)
+    fn = CONF.category.action_fn
+
+    fn_args = fetch_func_args(fn)
+    fn(*fn_args)
