@@ -1,6 +1,6 @@
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -15,29 +15,24 @@
 # under the License.
 import sys
 
+from oslo.config import cfg
 from oslo_log import log as logging
-from oslo_reports import guru_meditation_report as gmr
-from oslo_reports import opts as gmr_opts
 
-import designate.conf
-from designate import heartbeat_emitter
-from designate.mdns import service as mdns_service
 from designate import service
 from designate import utils
-from designate import version
+from designate.mdns import service as mdns_service
 
 
-CONF = designate.conf.CONF
+CONF = cfg.CONF
+CONF.import_opt('workers', 'designate.mdns', group='service:mdns')
+CONF.import_opt('threads', 'designate.mdns', group='service:mdns')
 
 
 def main():
     utils.read_config('designate', sys.argv)
     logging.setup(CONF, 'designate')
-    gmr_opts.set_defaults(CONF)
-    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
+    utils.setup_gmr(log_dir=cfg.CONF.log_dir)
 
-    server = mdns_service.Service()
-    heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
+    server = mdns_service.Service(threads=CONF['service:mdns'].threads)
     service.serve(server, workers=CONF['service:mdns'].workers)
-    heartbeat.start()
     service.wait()
