@@ -23,6 +23,7 @@ class Base(Exception):
 
     def __init__(self, *args, **kwargs):
         self.errors = kwargs.pop('errors', None)
+        self.object = kwargs.pop('object', None)
 
         super(Base, self).__init__(*args, **kwargs)
 
@@ -34,6 +35,16 @@ class Backend(Exception):
     pass
 
 
+class RelationNotLoaded(Base):
+    error_code = 500
+    error_type = 'relation_not_loaded'
+
+
+class AdapterNotFound(Base):
+    error_code = 500
+    error_type = 'adapter_not_found'
+
+
 class NSD4SlaveBackendError(Backend):
     pass
 
@@ -42,6 +53,10 @@ class NotImplemented(Base, NotImplementedError):
     pass
 
 
+class XFRFailure(Base):
+    pass
+
+
 class ConfigurationError(Base):
     error_type = 'configuration_error'
 
@@ -68,6 +83,11 @@ class NoServersConfigured(ConfigurationError):
     error_type = 'no_servers_configured'
 
 
+class NoPoolTargetsConfigured(ConfigurationError):
+    error_code = 500
+    error_type = 'no_pool_targets_configured'
+
+
 class OverQuota(Base):
     error_code = 413
     error_type = 'over_quota'
@@ -80,11 +100,13 @@ class QuotaResourceUnknown(Base):
 class InvalidObject(Base):
     error_code = 400
     error_type = 'invalid_object'
+    expected = True
 
 
 class BadRequest(Base):
     error_code = 400
     error_type = 'bad_request'
+    expected = True
 
 
 class InvalidUUID(BadRequest):
@@ -154,6 +176,11 @@ class InvalidRecordSetLocation(Base):
     error_type = 'invalid_recordset_location'
 
 
+class InvaildZoneTransfer(Base):
+    error_code = 400
+    error_type = 'invalid_zone_transfer_request'
+
+
 class InvalidTTL(Base):
     error_code = 400
     error_type = 'invalid_ttl'
@@ -170,6 +197,10 @@ class Forbidden(Base):
     expected = True
 
 
+class IncorrectZoneTransferKey(Forbidden):
+    error_type = 'invalid_key'
+
+
 class Duplicate(Base):
     expected = True
     error_code = 409
@@ -208,12 +239,40 @@ class DuplicateBlacklist(Duplicate):
     error_type = 'duplicate_blacklist'
 
 
+class DuplicatePoolManagerStatus(Duplicate):
+    error_type = 'duplication_pool_manager_status'
+
+
+class DuplicatePool(Duplicate):
+    error_type = 'duplicate_pool'
+
+
+class DuplicatePoolAttribute(Duplicate):
+    error_type = 'duplicate_pool_attribute'
+
+
+class DuplicateDomainAttribute(Duplicate):
+    error_type = 'duplicate_domain_attribute'
+
+
+class DuplicatePoolNsRecord(Duplicate):
+    error_type = 'duplicate_pool_ns_record'
+
+
 class MethodNotAllowed(Base):
     expected = True
     error_code = 405
     error_type = 'method_not_allowed'
 
 
+class DuplicateZoneTransferRequest(Duplicate):
+    error_type = 'duplicate_zone_transfer_request'
+
+
+class DuplicateZoneTransferAccept(Duplicate):
+    error_type = 'duplicate_zone_transfer_accept'
+
+
 class NotFound(Base):
     expected = True
     error_code = 404
@@ -240,6 +299,10 @@ class DomainNotFound(NotFound):
     error_type = 'domain_not_found'
 
 
+class DomainAttributeNotFound(NotFound):
+    error_type = 'domain_attribute_not_found'
+
+
 class TldNotFound(NotFound):
     error_type = 'tld_not_found'
 
@@ -256,6 +319,30 @@ class ReportNotFound(NotFound):
     error_type = 'report_not_found'
 
 
+class PoolManagerStatusNotFound(NotFound):
+    error_type = 'pool_manager_status_not_found'
+
+
+class PoolNotFound(NotFound):
+    error_type = 'pool_not_found'
+
+
+class PoolAttributeNotFound(NotFound):
+    error_type = 'pool_attribute_not_found'
+
+
+class PoolNsRecordNotFound(NotFound):
+    error_type = 'pool_ns_record_not_found'
+
+
+class ZoneTransferRequestNotFound(NotFound):
+    error_type = 'zone_transfer_request_not_found'
+
+
+class ZoneTransferAcceptNotFound(NotFound):
+    error_type = 'zone_transfer_accept_not_found'
+
+
 class LastServerDeleteNotAllowed(BadRequest):
     error_type = 'last_server_delete_not_allowed'
 
