@@ -12,27 +12,19 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from oslo_config import cfg
+from oslo.config import cfg
 from oslo_log import log as logging
-import oslo_messaging as messaging
+from oslo import messaging
 
-from designate.common import profiler
-from designate.loggingutils import rpc_logging
+from designate.i18n import _LI
 from designate import rpc
 
-CONF = cfg.CONF
+
 LOG = logging.getLogger(__name__)
 
 MDNS_API = None
 
 
-def reset():
-    global MDNS_API
-    MDNS_API = None
-
-
-@profiler.trace_cls("rpc")
-@rpc_logging(LOG, 'mdns')
 class MdnsAPI(object):
 
     """
@@ -42,23 +34,22 @@ class MdnsAPI(object):
 
         1.0 - Added notify_zone_changed and poll_for_serial_number.
         1.1 - Added get_serial_number.
-        2.0 - Changed method signatures
 
     XFR API version history:
         1.0 - Added perform_zone_xfr.
     """
-    RPC_NOTIFY_API_VERSION = '2.0'
+    RPC_NOTIFY_API_VERSION = '1.1'
     RPC_XFR_API_VERSION = '1.0'
 
     def __init__(self, topic=None):
-        self.topic = topic if topic else cfg.CONF['service:mdns'].topic
+        topic = topic if topic else cfg.CONF.mdns_topic
 
-        notify_target = messaging.Target(topic=self.topic,
+        notify_target = messaging.Target(topic=topic,
                                          namespace='notify',
                                          version=self.RPC_NOTIFY_API_VERSION)
-        self.notify_client = rpc.get_client(notify_target, version_cap='2.0')
+        self.notify_client = rpc.get_client(notify_target, version_cap='1.1')
 
-        xfr_target = messaging.Target(topic=self.topic,
+        xfr_target = messaging.Target(topic=topic,
                                       namespace='xfr',
                                       version=self.RPC_XFR_API_VERSION)
         self.xfr_client = rpc.get_client(xfr_target, version_cap='1.0')
@@ -77,68 +68,51 @@ class MdnsAPI(object):
             MDNS_API = cls()
         return MDNS_API
 
-    def notify_zone_changed(self, context, zone, host, port, timeout,
+    def notify_zone_changed(self, context, domain, nameserver, timeout,
                             retry_interval, max_retries, delay):
-        if CONF['service:worker'].notify:
-            LOG.debug('Letting worker send NOTIFYs instead')
-            return True
-
-        LOG.info(
-            "notify_zone_changed: Calling mdns for zone '%(zone)s', "
-            "serial '%(serial)s' to nameserver '%(host)s:%(port)s'",
-            {
-                'zone': zone.name,
-                'serial': zone.serial,
-                'host': host,
-                'port': port
-            })
+        LOG.info(_LI("notify_zone_changed: Calling mdns for zone '%(zone)s', "
+                     "serial '%(serial)s' to nameserver '%(host)s:%(port)s'") %
+                 {'zone': domain.name, 'serial': domain.serial,
+                  'host': nameserver.host, 'port': nameserver.port})
         # The notify_zone_changed method is a cast rather than a call since the
         # caller need not wait for the notify to complete.
         return self.notify_client.cast(
-            context, 'notify_zone_changed', zone=zone,
-            host=host, port=port, timeout=timeout,
-            retry_interval=retry_interval, max_retries=max_retries,
-            delay=delay)
-
-    def poll_for_serial_number(self, context, zone, nameserver, timeout,
-                               retry_interval, max_retries, delay):
-        LOG.info(
-            "poll_for_serial_number: Calling mdns for zone '%(zone)s', "
-            "serial '%(serial)s' on nameserver '%(host)s:%(port)s'",
-            {
-                'zone': zone.name,
-                'serial': zone.serial,
-                'host': nameserver.host,
-                'port': nameserver.port
-            })
-        # The poll_for_serial_number method is a cast rather than a call since
-        # the caller need not wait for the poll to complete. Mdns informs pool
-        # manager of the return value using update_status
-        return self.notify_client.cast(
-            context, 'poll_for_serial_number', zone=zone,
+            context, 'notify_zone_changed', domain=domain,
             nameserver=nameserver, timeout=timeout,
             retry_interval=retry_interval, max_retries=max_retries,
             delay=delay)
 
-    def get_serial_number(self, context, zone, host, port, timeout,
-                          retry_interval, max_retries, delay):
+    def poll_for_serial_number(self, context, domain, nameserver, timeout,
+                               retry_interval, max_retries, delay):
         LOG.info(
-            "get_serial_number: Calling mdns for zone '%(zone)s', serial "
-            "%(serial)s' on nameserver '%(host)s:%(port)s'",
-            {
-                'zone': zone.name,
-                'serial': zone.serial,
-                'host': host,
-                'port': port
-            })
-        cctxt = self.notify_client.prepare()
-        return cctxt.call(
-            context, 'get_serial_number', zone=zone,
-            host=host, port=port, timeout=timeout,
+            _LI("poll_for_serial_number: Calling mdns for zone '%(zone)s', "
+                "serial '%(serial)s' on nameserver '%(host)s:%(port)s'") %
+            {'zone': domain.name, 'serial': domain.serial,
+             'host': nameserver.host, 'port': nameserver.port})
+        # The poll_for_serial_number method is a cast rather than a call since
+        # the caller need not wait for the poll to complete. Mdns informs pool
+        # manager of the return value using update_status
+        return self.notify_client.cast(
+            context, 'poll_for_serial_number', domain=domain,
+            nameserver=nameserver, timeout=timeout,
             retry_interval=retry_interval, max_retries=max_retries,
             delay=delay)
 
-    def perform_zone_xfr(self, context, zone):
-        LOG.info("perform_zone_xfr: Calling mdns for zone %(zone)s",
-                 {"zone": zone.name})
-        return self.xfr_client.cast(context, 'perform_zone_xfr', zone=zone)
+    def get_serial_number(self, context, domain, nameserver, timeout,
+                          retry_interval, max_retries, delay):
+        LOG.info(
+            _LI("get_serial_number: Calling mdns for zone '%(zone)s', serial "
+                "%(serial)s' on nameserver '%(host)s:%(port)s'") %
+            {'zone': domain.name, 'serial': domain.serial,
+             'host': nameserver.host, 'port': nameserver.port})
+        cctxt = self.notify_client.prepare(version='1.1')
+        return cctxt.call(
+            context, 'get_serial_number', domain=domain,
+            nameserver=nameserver, timeout=timeout,
+            retry_interval=retry_interval, max_retries=max_retries,
+            delay=delay)
+
+    def perform_zone_xfr(self, context, domain):
+        LOG.info(_LI("perform_zone_xfr: Calling mdns for zone %(zone)s") %
+                 {"zone": domain.name})
+        return self.xfr_client.cast(context, 'perform_zone_xfr', domain=domain)
