@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hpe.com>
+# Author: Endre Karlson <endre.karlson@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -14,7 +14,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import eventlet.patcher
-from oslo_config import cfg
+from oslo.config import cfg
 from oslo_log import log as logging
 
 from designate import exceptions
@@ -57,7 +57,7 @@ class NetworkAPI(DriverPlugin):
             msg = 'No service_catalog and no configured endpoints'
             raise exceptions.ConfigurationError(msg)
 
-        LOG.debug('Returning endpoints: %s', endpoints)
+        LOG.debug('Returning endpoints: %s' % endpoints)
         return endpoints
 
     def _endpoints_from_catalog(self, service_catalog, service_type,
@@ -108,4 +108,4 @@ class NetworkAPI(DriverPlugin):
         """
         Get the name for the address
         """
-        return reversename.from_address(address).to_text().decode('utf-8')
+        return reversename.from_address(address).to_text()
