@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Endre Karlson <endre.karlson@hpe.com>
+# Author: Endre Karlson <endre.karlson@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,16 +13,16 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
+import uuid
 
 from oslo_log import log as logging
 
-from designate.network_api import base
-from designate.utils import generate_uuid
+from designate.network_api.base import NetworkAPI
 
 
 LOG = logging.getLogger(__name__)
-POOL = {generate_uuid(): '192.0.2.%s' % i for i in range(1, 254)}
+
+POOL = dict([(str(uuid.uuid4()), '192.168.2.%s' % i) for i in xrange(0, 254)])
 ALLOCATIONS = {}
 
 
@@ -34,17 +34,17 @@ def _format_floatingip(id_, address):
     }
 
 
-def allocate_floatingip(project_id, floatingip_id=None):
+def allocate_floatingip(tenant_id, floatingip_id=None):
     """
-    Allocates a floating ip from the pool to the project.
+    Allocates a floating ip from the pool to the tenant.
     """
-    ALLOCATIONS.setdefault(project_id, {})
+    ALLOCATIONS.setdefault(tenant_id, {})
 
-    id_ = floatingip_id or list(POOL.keys())[0]
+    id_ = floatingip_id or POOL.keys()[0]
 
-    ALLOCATIONS[project_id][id_] = POOL.pop(id_)
-    values = _format_floatingip(id_, ALLOCATIONS[project_id][id_])
-    LOG.debug('Allocated to id_ %s to %s - %s', id_, project_id, values)
+    ALLOCATIONS[tenant_id][id_] = POOL.pop(id_)
+    values = _format_floatingip(id_, ALLOCATIONS[tenant_id][id_])
+    LOG.debug("Allocated to id_ %s to %s - %s" % (id_, tenant_id, values))
     return values
 
 
@@ -52,33 +52,34 @@ def deallocate_floatingip(id_):
     """
     Deallocate a floatingip
     """
-    LOG.debug('De-allocating %s', id_)
-    for project_id, allocated in list(ALLOCATIONS.items()):
+    LOG.debug('De-allocating %s' % id_)
+    for tenant_id, allocated in ALLOCATIONS.items():
         if id_ in allocated:
             POOL[id_] = allocated.pop(id_)
             break
+    else:
+        raise KeyError('No such FloatingIP %s' % id_)
 
 
 def reset_floatingips():
     LOG.debug('Resetting any allocations.')
-    for project_id, allocated in list(ALLOCATIONS.items()):
-        for key, value in list(allocated.items()):
+    for tenant_id, allocated in ALLOCATIONS.items():
+        for key, value in allocated.items():
             POOL[key] = allocated.pop(key)
 
 
-class FakeNetworkAPI(base.NetworkAPI):
+class FakeNetworkAPI(NetworkAPI):
     __plugin_name__ = 'fake'
 
     def list_floatingips(self, context, region=None):
         if context.is_admin:
             data = []
-            for project_id, allocated in list(ALLOCATIONS.items()):
-                data.extend(list(allocated.items()))
+            for tenant_id, allocated in ALLOCATIONS.items():
+                data.extend(allocated.items())
         else:
-            data = list(ALLOCATIONS.get(context.project_id, {}).items())
+            data = ALLOCATIONS.get(context.tenant, {}).items()
 
         formatted = [_format_floatingip(k, v) for k, v in data]
-        LOG.debug(
-            'Returning %i FloatingIPs: %s', len(formatted), formatted
-        )
+        LOG.debug('Returning %i FloatingIPs: %s' %
+                  (len(formatted), formatted))
         return formatted
