@@ -15,15 +15,20 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import abc
+
 from oslo.config import cfg
-from designate.openstack.common import log as logging
+from oslo_log import log as logging
+
+from designate import exceptions
 from designate.central import rpcapi as central_rpcapi
 from designate.context import DesignateContext
-from designate.plugin import Plugin
+from designate.i18n import _LW
+from designate.objects import Record
+from designate.objects import RecordSet
+from designate.plugin import ExtensionPlugin
 
 
 LOG = logging.getLogger(__name__)
-central_api = central_rpcapi.CentralAPI()
 
 
 def get_ip_data(addr_dict):
@@ -43,11 +48,15 @@ def get_ip_data(addr_dict):
     return data
 
 
-class Handler(Plugin):
-    """ Base class for notification handlers """
+class NotificationHandler(ExtensionPlugin):
+    """Base class for notification handlers"""
     __plugin_ns__ = 'designate.notification.handler'
     __plugin_type__ = 'handler'
 
+    def __init__(self, *args, **kw):
+        super(NotificationHandler, self).__init__(*args, **kw)
+        self.central_api = central_rpcapi.CentralAPI()
+
     @abc.abstractmethod
     def get_exchange_topics(self):
         """
@@ -62,18 +71,37 @@ class Handler(Plugin):
         """
 
     @abc.abstractmethod
-    def process_notification(self, event_type, payload):
-        """ Processes a given notification """
+    def process_notification(self, context, event_type, payload):
+        """Processes a given notification"""
 
     def get_domain(self, domain_id):
         """
         Return the domain for this context
         """
-        context = DesignateContext.get_admin_context()
-        return central_api.get_domain(context, domain_id)
+        context = DesignateContext.get_admin_context(all_tenants=True)
+        return self.central_api.get_domain(context, domain_id)
+
+    def _find_or_create_recordset(self, context, domain_id, name, type,
+                                  ttl=None):
+        try:
+            recordset = self.central_api.find_recordset(context, {
+                'domain_id': domain_id,
+                'name': name,
+                'type': type,
+            })
+        except exceptions.RecordSetNotFound:
+            values = {
+                'name': name,
+                'type': type,
+                'ttl': ttl,
+            }
+            recordset = self.central_api.create_recordset(
+                context, domain_id, RecordSet(**values))
+
+        return recordset
 
 
-class BaseAddressHandler(Handler):
+class BaseAddressHandler(NotificationHandler):
     default_format = '%(octet0)s-%(octet1)s-%(octet2)s-%(octet3)s.%(domain)s'
 
     def _get_format(self):
@@ -91,6 +119,11 @@ class BaseAddressHandler(Handler):
         :param resource_type: The managed resource type
         :param resource_id: The managed resource ID
         """
+        if not managed:
+            LOG.warning(_LW(
+                'Deprecation notice: Unmanaged designate-sink records are '
+                'being deprecated please update the call '
+                'to remove managed=False'))
         LOG.debug('Using DomainID: %s' % cfg.CONF[self.name].domain_id)
         domain = self.get_domain(cfg.CONF[self.name].domain_id)
         LOG.debug('Domain: %r' % domain)
@@ -99,17 +132,25 @@ class BaseAddressHandler(Handler):
         LOG.debug('Event data: %s' % data)
         data['domain'] = domain['name']
 
-        context = DesignateContext.get_admin_context()
+        context = DesignateContext().elevated()
+        context.all_tenants = True
+        context.edit_managed_records = True
 
         for addr in addresses:
-            record_data = data.copy()
-            record_data.update(get_ip_data(addr))
+            event_data = data.copy()
+            event_data.update(get_ip_data(addr))
+
+            recordset_values = {
+                'domain_id': domain['id'],
+                'name': self._get_format() % event_data,
+                'type': 'A' if addr['version'] == 4 else 'AAAA'}
+
+            recordset = self._find_or_create_recordset(
+                context, **recordset_values)
 
-            record_name = self._get_format() % record_data
             record_values = {
-                'type': 'A' if addr['version'] == 4 else 'AAAA',
-                'name': record_name,
                 'data': addr['address']}
+
             if managed:
                 record_values.update({
                     'managed': managed,
@@ -117,18 +158,33 @@ class BaseAddressHandler(Handler):
                     'managed_plugin_type': self.get_plugin_type(),
                     'managed_resource_type': resource_type,
                     'managed_resource_id': resource_id})
-            LOG.debug('Creating record in %s with values %r', domain['id'],
-                      record_values)
-            central_api.create_record(context, domain['id'], record_values)
+
+            LOG.debug('Creating record in %s / %s with values %r' %
+                      (domain['id'], recordset['id'], record_values))
+            self.central_api.create_record(context,
+                                           domain['id'],
+                                           recordset['id'],
+                                           Record(**record_values))
 
     def _delete(self, managed=True, resource_id=None, resource_type='instance',
-                criterion={}):
+                criterion=None):
         """
         Handle a generic delete of a fixed ip within a domain
 
         :param criterion: Criterion to search and destroy records
         """
-        context = DesignateContext.get_admin_context()
+        if not managed:
+            LOG.warning(_LW(
+                'Deprecation notice: Unmanaged designate-sink records are '
+                'being deprecated please update the call '
+                'to remove managed=False'))
+        criterion = criterion or {}
+
+        context = DesignateContext().elevated()
+        context.all_tenants = True
+        context.edit_managed_records = True
+
+        criterion.update({'domain_id': cfg.CONF[self.name].domain_id})
 
         if managed:
             criterion.update({
@@ -139,12 +195,12 @@ class BaseAddressHandler(Handler):
                 'managed_resource_type': resource_type
             })
 
-        records = central_api.find_records(context,
-                                           cfg.CONF[self.name].domain_id,
-                                           criterion)
+        records = self.central_api.find_records(context, criterion)
 
         for record in records:
             LOG.debug('Deleting record %s' % record['id'])
 
-            central_api.delete_record(context, cfg.CONF[self.name].domain_id,
-                                      record['id'])
+            self.central_api.delete_record(context,
+                                           cfg.CONF[self.name].domain_id,
+                                           record['recordset_id'],
+                                           record['id'])
