@@ -13,38 +13,28 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
+from oslo.config import cfg
 from oslo_log import log as logging
 
-from designate.notification_handler import base
+from designate.notification_handler.base import BaseAddressHandler
 
 
 LOG = logging.getLogger(__name__)
 
-# TODO(trungnv): update default format for v4 and v6 in these cfg.
-neutron_group = cfg.OptGroup(
+cfg.CONF.register_group(cfg.OptGroup(
     name='handler:neutron_floatingip',
     title="Configuration for Neutron Notification Handler"
-)
+))
 
-neutron_opts = [
-    cfg.ListOpt('notification-topics', default=['notifications'],
-                help='notification any events from neutron'),
-    cfg.StrOpt('control-exchange', default='neutron',
-               help='control-exchange for neutron notification'),
-    cfg.StrOpt('zone-id', help='Zone ID with each notification'),
-    cfg.MultiStrOpt('formatv4', help='IPv4 format'),
-    cfg.MultiStrOpt('format', deprecated_for_removal=True,
-                deprecated_reason="Replaced by 'formatv4/formatv6'",
-                help='format which replaced by formatv4/formatv6'),
-    cfg.MultiStrOpt('formatv6', help='IPv6 format')
-]
-
-cfg.CONF.register_group(neutron_group)
-cfg.CONF.register_opts(neutron_opts, group=neutron_group)
+cfg.CONF.register_opts([
+    cfg.ListOpt('notification-topics', default=['notifications']),
+    cfg.StrOpt('control-exchange', default='neutron'),
+    cfg.StrOpt('domain-id', default=None),
+    cfg.StrOpt('format', default=None)
+], group='handler:neutron_floatingip')
 
 
-class NeutronFloatingHandler(base.BaseAddressHandler):
+class NeutronFloatingHandler(BaseAddressHandler):
     """Handler for Neutron's notifications"""
     __plugin_name__ = 'neutron_floatingip'
 
@@ -62,28 +52,20 @@ class NeutronFloatingHandler(base.BaseAddressHandler):
         ]
 
     def process_notification(self, context, event_type, payload):
-        LOG.debug('%s received notification - %s',
-                  self.get_canonical_name(), event_type)
+        LOG.debug('%s received notification - %s' %
+                  (self.get_canonical_name(), event_type))
 
-        zone_id = cfg.CONF[self.name].zone_id
         if event_type.startswith('floatingip.delete'):
-            self._delete(zone_id=zone_id,
-                         resource_id=payload['floatingip_id'],
+            self._delete(resource_id=payload['floatingip_id'],
                          resource_type='floatingip')
         elif event_type.startswith('floatingip.update'):
             if payload['floatingip']['fixed_ip_address']:
                 address = {
                     'version': 4,
-                    'address': payload['floatingip']['floating_ip_address']
-                }
-                payload['floatingip']['project'] = context.get(
-                             "project_name", None)
-                self._create(addresses=[address],
-                             extra=payload['floatingip'],
-                             zone_id=zone_id,
+                    'address': payload['floatingip']['floating_ip_address']}
+                self._create([address], payload['floatingip'],
                              resource_id=payload['floatingip']['id'],
                              resource_type='floatingip')
-            else:
-                self._delete(zone_id=zone_id,
-                             resource_id=payload['floatingip']['id'],
+            elif not payload['floatingip']['fixed_ip_address']:
+                self._delete(resource_id=payload['floatingip']['id'],
                              resource_type='floatingip')
