@@ -15,7 +15,6 @@ from oslo_log import log as logging
 
 from designate.objects.adapters.api_v2 import base
 from designate import objects
-
 LOG = logging.getLogger(__name__)
 
 
@@ -63,15 +62,11 @@ class DomainAPIv2Adapter(base.APIv2Adapter):
 
     @classmethod
     def _parse_object(cls, values, object, *args, **kwargs):
+        # TODO(Graham): Remove this when
+        # https://bugs.launchpad.net/designate/+bug/1432842 is fixed
 
         if 'masters' in values:
-
-            object.masters = objects.adapters.DesignateAdapter.parse(
-                cls.ADAPTER_FORMAT,
-                values['masters'],
-                objects.DomainMasterList(),
-                *args, **kwargs)
-
+            object.set_masters(values.get('masters'))
             del values['masters']
 
         return super(DomainAPIv2Adapter, cls)._parse_object(
