@@ -17,18 +17,13 @@ from designate import exceptions
 from designate.objects import base
 from designate.objects.validation_error import ValidationError
 from designate.objects.validation_error import ValidationErrorList
+from designate.objects.domain_attribute import DomainAttribute
+from designate.objects.domain_attribute import DomainAttributeList
 
 
 class Domain(base.DictObjectMixin, base.SoftDeleteObjectMixin,
              base.PersistentObjectMixin, base.DesignateObject):
     FIELDS = {
-        'shard': {
-            'schema': {
-                'type': 'integer',
-                'minimum': 0,
-                'maximum': 4095
-            }
-        },
         'tenant_id': {
             'schema': {
                 'type': 'string',
@@ -52,12 +47,12 @@ class Domain(base.DictObjectMixin, base.SoftDeleteObjectMixin,
                 'format': 'email',
                 'maxLength': 255
             },
-            'required': False
+            'required': True
         },
         'ttl': {
             'schema': {
                 'type': ['integer', 'null'],
-                'minimum': 1,
+                'minimum': 0,
                 'maximum': 2147483647
             },
         },
@@ -143,10 +138,6 @@ class Domain(base.DictObjectMixin, base.SoftDeleteObjectMixin,
             'relation': True,
             'relation_cls': 'DomainAttributeList'
         },
-        'masters': {
-            'relation': True,
-            'relation_cls': 'DomainMasterList'
-        },
         'type': {
             'schema': {
                 'type': 'string',
@@ -163,77 +154,46 @@ class Domain(base.DictObjectMixin, base.SoftDeleteObjectMixin,
         },
     }
 
-    STRING_KEYS = [
-        'id', 'type', 'name', 'pool_id', 'serial', 'action', 'status'
-    ]
+    @property
+    def masters(self):
+        if self.obj_attr_is_set('attributes'):
+            return [i.value for i in self.attributes if i.key == 'master']
+        else:
+            return None
+
+    # TODO(ekarlso): Make this a property sette rpr Kiall's comments later.
+    def set_masters(self, masters):
+        attributes = DomainAttributeList()
+
+        for m in masters:
+            obj = DomainAttribute(key='master', value=m)
+            attributes.append(obj)
+        self.attributes = attributes
 
     def get_master_by_ip(self, host):
         """
         Utility to get the master by it's ip for this domain.
         """
         for srv in self.masters:
-            srv_host, _ = utils.split_host_port(srv.to_data())
+            srv_host, _ = utils.split_host_port(srv)
             if host == srv_host:
                 return srv
         return False
 
-    def _raise(self, errors):
-        if len(errors) != 0:
-            raise exceptions.InvalidObject(
-                "Provided object does not match "
-                "schema", errors=errors, object=self)
-
     def validate(self):
-        errors = ValidationErrorList()
-
-        if self.type == 'PRIMARY':
-            if self.obj_attr_is_set('masters') and len(self.masters) != 0:
-                e = ValidationError()
-                e.path = ['type']
-                e.validator = 'maxItems'
-                e.validator_value = ['masters']
-                e.message = "'masters' has more items than allowed"
-                errors.append(e)
-            if self.email is None:
-                e = ValidationError()
-                e.path = ['type']
-                e.validator = 'required'
-                e.validator_value = 'email'
-                e.message = "'email' is a required property"
-                errors.append(e)
-            self._raise(errors)
-
-        try:
-            if self.type == 'SECONDARY':
-                if self.masters is None or len(self.masters) == 0:
-                    e = ValidationError()
-                    e.path = ['type']
-                    e.validator = 'required'
-                    e.validator_value = ['masters']
-                    e.message = "'masters' is a required property"
-                    errors.append(e)
-
-                for i in ['email', 'ttl']:
-                    if i in self.obj_what_changed():
-                        e = ValidationError()
-                        e.path = ['type']
-                        e.validator = 'not_allowed'
-                        e.validator_value = i
-                        e.message = "'%s' can't be specified when type is " \
-                            "SECONDARY" % i
-                        errors.append(e)
-                self._raise(errors)
-
-            super(Domain, self).validate()
-        except exceptions.RelationNotLoaded as ex:
+        if self.type == 'SECONDARY' and self.masters is None:
             errors = ValidationErrorList()
             e = ValidationError()
             e.path = ['type']
             e.validator = 'required'
-            e.validator_value = [ex.relation]
-            e.message = "'%s' is a required property" % ex.relation
+            e.validator_value = ['masters']
+            e.message = "'masters' is a required property"
             errors.append(e)
-            self._raise(errors)
+            raise exceptions.InvalidObject(
+                "Provided object does not match "
+                "schema", errors=errors, object=self)
+
+        super(Domain, self).validate()
 
 
 class DomainList(base.ListObjectMixin, base.DesignateObject,
