@@ -13,27 +13,34 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 from designate.objects import base
-from designate.objects import fields
 
 
-@base.DesignateRegistry.register
 class PoolAttribute(base.DictObjectMixin, base.PersistentObjectMixin,
                     base.DesignateObject):
-    fields = {
-        'pool_id': fields.UUIDFields(nullable=True),
-        'key': fields.StringFields(maxLength=50),
-        'value': fields.StringFields(maxLength=50)
-
+    FIELDS = {
+        'pool_id': {
+            'schema': {
+                'type': 'string',
+                'description': 'Pool identifier',
+                'format': 'uuid',
+            },
+        },
+        'key': {
+            'schema': {
+                'type': 'string',
+                'maxLength': 50,
+            },
+            'required': True,
+        },
+        'value': {
+            'schema': {
+                'type': 'string',
+                'maxLength': 50,
+            },
+            'required': True
+        }
     }
 
-    STRING_KEYS = [
-        'id', 'key', 'value', 'pool_id'
-    ]
 
-
-@base.DesignateRegistry.register
-class PoolAttributeList(base.AttributeListObjectMixin, base.DesignateObject):
+class PoolAttributeList(base.ListObjectMixin, base.DesignateObject):
     LIST_ITEM_TYPE = PoolAttribute
-    fields = {
-        'objects': fields.ListOfObjectsField('PoolAttribute'),
-    }
