@@ -13,27 +13,38 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 from designate.objects import base
-from designate.objects import fields
 
 
-@base.DesignateRegistry.register
 class PoolNsRecord(base.DictObjectMixin, base.PersistentObjectMixin,
                    base.DesignateObject):
-    fields = {
-        'pool_id': fields.UUIDFields(nullable=True),
-        'priority': fields.IntegerFields(minimum=1, maximum=10000),
-        'hostname': fields.DomainField(maxLength=255),
-
+    FIELDS = {
+        'pool_id': {
+            'schema': {
+                'type': 'string',
+                'description': 'Pool identifier',
+                'format': 'uuid',
+            },
+        },
+        'priority': {
+            'schema': {
+                'type': 'integer',
+                'description': 'NS Record Priority Order',
+                'minimum': 1,
+                'maximum': 10000
+            },
+        },
+        'hostname': {
+            'schema': {
+                'type': 'string',
+                'description': 'NS Record Hostname',
+                'format': 'domainname',
+                'maxLength': 255,
+            },
+            'immutable': True,
+            'required': True
+        }
     }
 
-    STRING_KEYS = [
-        'id', 'hostname', 'priority', 'pool_id'
-    ]
 
-
-@base.DesignateRegistry.register
 class PoolNsRecordList(base.ListObjectMixin, base.DesignateObject):
     LIST_ITEM_TYPE = PoolNsRecord
-    fields = {
-        'objects': fields.ListOfObjectsField('PoolNsRecord'),
-    }
