@@ -13,16 +13,16 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
+from oslo.config import cfg
 
 CONF = cfg.CONF
 
-pool_manager_group = cfg.OptGroup(
+CONF.register_group(cfg.OptGroup(
     name='service:pool_manager', title="Configuration for Pool Manager Service"
-)
+))
 
 OPTS = [
-    cfg.IntOpt('workers',
+    cfg.IntOpt('workers', default=None,
                help='Number of Pool Manager worker processes to spawn'),
     cfg.IntOpt('threads', default=1000,
                help='Number of Pool Manager greenthreads to spawn'),
@@ -31,28 +31,18 @@ OPTS = [
                     'Pool Manager'),
     cfg.IntOpt('threshold-percentage', default=100,
                help='The percentage of servers requiring a successful update '
-                    'for a zone change to be considered active',
-                    deprecated_for_removal=True,
-                    deprecated_reason='Migrated to designate-worker'),
+                    'for a domain change to be considered active'),
     cfg.IntOpt('poll-timeout', default=30,
-               help='The time to wait for a response from a server',
-               deprecated_for_removal=True,
-               deprecated_reason='Migrated to designate-worker'),
-    cfg.IntOpt('poll-retry-interval', default=15,
+               help='The time to wait for a response from a server'),
+    cfg.IntOpt('poll-retry-interval', default=2,
                help='The time between retrying to send a request and '
-                    'waiting for a response from a server',
-               deprecated_for_removal=True,
-               deprecated_reason='Migrated to designate-worker'),
-    cfg.IntOpt('poll-max-retries', default=10,
+                    'waiting for a response from a server'),
+    cfg.IntOpt('poll-max-retries', default=3,
                help='The maximum number of times to retry sending a request '
-                    'and wait for a response from a server',
-               deprecated_for_removal=True,
-               deprecated_reason='Migrated to designate-worker'),
-    cfg.IntOpt('poll-delay', default=5,
+                    'and wait for a response from a server'),
+    cfg.IntOpt('poll-delay', default=1,
                help='The time to wait before sending the first request '
-                    'to a server',
-               deprecated_for_removal=True,
-               deprecated_reason='Migrated to designate-worker'),
+                    'to a server'),
     cfg.BoolOpt('enable-recovery-timer', default=True,
                 help='The flag for the recovery timer'),
     cfg.IntOpt('periodic-recovery-interval', default=120,
@@ -62,18 +52,14 @@ OPTS = [
     cfg.IntOpt('periodic-sync-interval', default=1800,
                help='The time between synchronizing the servers with storage'),
     cfg.IntOpt('periodic-sync-seconds', default=21600,
-               help='Zones Updated within last N seconds will be syncd.'
-                    'Use an empty value to sync all zones.'),
-    cfg.IntOpt('periodic-sync-max-attempts', default=3,
-               help='Number of attempts to update a zone during sync'),
-    cfg.IntOpt('periodic-sync-retry-interval', default=30,
-               help='Interval between zone update attempts during sync'),
-    cfg.StrOpt('cache-driver', default='memcache',
+               help='Zones Updated within last N seconds will be syncd. Use '
+                    'None to sync all zones.'),
+    cfg.StrOpt('cache-driver', default='sqlalchemy',
                help='The cache driver to use'),
-    cfg.StrOpt('pool_manager_topic', default='pool_manager',
-               help='RPC topic name for pool-manager')
 ]
 
+CONF.register_opts(OPTS, group='service:pool_manager')
+
 
 def register_dynamic_pool_options():
     # Pool Options Registration Pass One
@@ -102,7 +88,7 @@ def register_dynamic_pool_options():
     pool_target_opts = [
         cfg.StrOpt('type'),
         cfg.ListOpt('masters', default=[]),
-        cfg.DictOpt('options', default={}, secret=True),
+        cfg.DictOpt('options', default={}),
     ]
 
     for pool_target_id in pool_target_ids:
@@ -126,11 +112,3 @@ def register_dynamic_pool_options():
 
         CONF.register_group(pool_nameserver_group)
         CONF.register_opts(pool_nameserver_opts, group=pool_nameserver_group)
-
-
-cfg.CONF.register_group(pool_manager_group)
-cfg.CONF.register_opts(OPTS, group=pool_manager_group)
-
-
-def list_opts():
-    yield pool_manager_group, OPTS
