@@ -13,14 +13,12 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
-from oslo_config import cfg
+from oslo.config import cfg
 from oslo_log import log as logging
-import oslo_messaging as messaging
+from oslo import messaging
 
 from designate.i18n import _LI
 from designate import rpc
-from designate.loggingutils import rpc_logging
 
 
 LOG = logging.getLogger(__name__)
@@ -28,12 +26,6 @@ LOG = logging.getLogger(__name__)
 MNGR_API = None
 
 
-def reset():
-    global MNGR_API
-    MNGR_API = None
-
-
-@rpc_logging(LOG, 'pool_manager')
 class PoolManagerAPI(object):
     """
     Client side of the Pool Manager RPC API.
@@ -43,18 +35,15 @@ class PoolManagerAPI(object):
         API version history:
 
         1.0 - Initial version
-        2.0 - Rename domains to zones
-        2.1 - Add target_sync
     """
-    RPC_API_VERSION = '2.1'
+    RPC_API_VERSION = '1.0'
 
     def __init__(self, topic=None):
-        self.topic = topic if topic \
-            else cfg.CONF['service:pool_manager'].pool_manager_topic
+        self.topic = topic if topic else cfg.CONF.pool_manager_topic
 
         target = messaging.Target(topic=self.topic,
                                   version=self.RPC_API_VERSION)
-        self.client = rpc.get_client(target, version_cap='2.1')
+        self.client = rpc.get_client(target, version_cap='1.0')
 
     @classmethod
     def get_instance(cls):
@@ -70,45 +59,51 @@ class PoolManagerAPI(object):
             MNGR_API = cls()
         return MNGR_API
 
-    def target_sync(self, context, pool_id, target_id, timestamp):
-        LOG.info(_LI("target_sync: Syncing target %(target) since "
-                     "%(timestamp)d."),
-                 {'target': target_id, 'timestamp': timestamp})
+    def create_domain(self, context, domain):
+        LOG.info(_LI("create_domain: Calling pool manager for %(domain)s, "
+                     "serial:%(serial)s") %
+                 {'domain': domain.name, 'serial': domain.serial})
 
         # Modifying the topic so it is pool manager instance specific.
-        topic = '%s.%s' % (self.topic, pool_id)
-        cctxt = self.client.prepare(topic=topic)
-        return cctxt.call(
-            context, 'target_sync', pool_id=pool_id, target_id=target_id,
-            timestamp=timestamp)
-
-    def create_zone(self, context, zone):
-        # Modifying the topic so it is pool manager instance specific.
-        topic = '%s.%s' % (self.topic, zone.pool_id)
+        topic = '%s.%s' % (self.topic, domain.pool_id)
         cctxt = self.client.prepare(topic=topic)
         return cctxt.cast(
-            context, 'create_zone', zone=zone)
+            context, 'create_domain', domain=domain)
+
+    def delete_domain(self, context, domain):
+        LOG.info(_LI("delete_domain: Calling pool manager for %(domain)s, "
+                     "serial:%(serial)s") %
+                 {'domain': domain.name, 'serial': domain.serial})
 
-    def delete_zone(self, context, zone):
         # Modifying the topic so it is pool manager instance specific.
-        topic = '%s.%s' % (self.topic, zone.pool_id)
+        topic = '%s.%s' % (self.topic, domain.pool_id)
         cctxt = self.client.prepare(topic=topic)
         return cctxt.cast(
-            context, 'delete_zone', zone=zone)
+            context, 'delete_domain', domain=domain)
+
+    def update_domain(self, context, domain):
+        LOG.info(_LI("update_domain: Calling pool manager for %(domain)s, "
+                     "serial:%(serial)s") %
+                 {'domain': domain.name, 'serial': domain.serial})
 
-    def update_zone(self, context, zone):
         # Modifying the topic so it is pool manager instance specific.
-        topic = '%s.%s' % (self.topic, zone.pool_id)
+        topic = '%s.%s' % (self.topic, domain.pool_id)
         cctxt = self.client.prepare(topic=topic)
         return cctxt.cast(
-            context, 'update_zone', zone=zone)
+            context, 'update_domain', domain=domain)
 
-    def update_status(self, context, zone, nameserver, status,
+    def update_status(self, context, domain, nameserver, status,
                       actual_serial):
+        LOG.info(_LI("update_status: Calling pool manager for %(domain)s : "
+                     "%(action)s : %(status)s : %(serial)s on nameserver "
+                     "'%(host)s:%(port)s'") %
+                 {'domain': domain.name, 'action': domain.action,
+                  'status': status, 'serial': actual_serial,
+                  'host': nameserver.host, 'port': nameserver.port})
 
         # Modifying the topic so it is pool manager instance specific.
-        topic = '%s.%s' % (self.topic, zone.pool_id)
+        topic = '%s.%s' % (self.topic, domain.pool_id)
         cctxt = self.client.prepare(topic=topic)
         return cctxt.cast(
-            context, 'update_status', zone=zone, nameserver=nameserver,
+            context, 'update_status', domain=domain, nameserver=nameserver,
             status=status, actual_serial=actual_serial)
