@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,24 +13,28 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+from oslo.config import cfg
 from oslo_log import log as logging
 
 from designate import exceptions
-from designate import objects
-from designate.quota import base
 from designate import storage
-from designate.storage import transaction
+from designate import objects
+from designate.central import service as central_service
+from designate.quota.base import Quota
 
 
 LOG = logging.getLogger(__name__)
 
 
-class StorageQuota(base.Quota):
+class StorageQuota(Quota):
     __plugin_name__ = 'storage'
 
     def __init__(self):
         super(StorageQuota, self).__init__()
-        self.storage = storage.get_storage()
+
+        # TODO(kiall): Should this be tied to central's config?
+        storage_driver = cfg.CONF['service:central'].storage_driver
+        self.storage = storage.get_storage(storage_driver)
 
     def _get_quotas(self, context, tenant_id):
         quotas = self.storage.find_quotas(context, {
@@ -50,37 +54,38 @@ class StorageQuota(base.Quota):
 
         return {resource: quota['hard_limit']}
 
-    @transaction
+    @central_service.transaction
     def set_quota(self, context, tenant_id, resource, hard_limit):
         context = context.deepcopy()
         context.all_tenants = True
 
-        if resource not in list(self.get_default_quotas(context).keys()):
+        def create_quota():
+            quota = objects.Quota(
+                tenant_id=tenant_id, resource=resource, hard_limit=hard_limit)
+
+            self.storage.create_quota(context, quota)
+
+        def update_quota(quota):
+            quota.hard_limit = hard_limit
+
+            self.storage.update_quota(context, quota)
+
+        if resource not in self.get_default_quotas(context).keys():
             raise exceptions.QuotaResourceUnknown("%s is not a valid quota "
-                                                  "resource" % resource)
+                                                  "resource", resource)
 
         try:
-            self._create_quota(context, tenant_id, resource, hard_limit)
+            create_quota()
         except exceptions.Duplicate:
             quota = self.storage.find_quota(context, {
                 'tenant_id': tenant_id,
                 'resource': resource,
             })
-            self._update_quota(context, quota, hard_limit)
+            update_quota(quota)
 
         return {resource: hard_limit}
 
-    def _create_quota(self, context, project_id, resource, hard_limit):
-        quota = objects.Quota(
-            tenant_id=project_id, resource=resource, hard_limit=hard_limit
-        )
-        self.storage.create_quota(context, quota)
-
-    def _update_quota(self, context, quota, hard_limit):
-        quota.hard_limit = hard_limit
-        self.storage.update_quota(context, quota)
-
-    @transaction
+    @central_service.transaction
     def reset_quotas(self, context, tenant_id):
         context = context.deepcopy()
         context.all_tenants = True
