@@ -12,18 +12,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
-import oslo_messaging as messaging
-from oslo_messaging.rpc import dispatcher as rpc_dispatcher
-from oslo_serialization import jsonutils
-from oslo_utils import importutils
-
-import designate.context
-import designate.exceptions
-from designate import objects
-
-profiler = importutils.try_import('osprofiler.profiler')
-
 __all__ = [
     'init',
     'cleanup',
@@ -35,14 +23,33 @@ __all__ = [
     'get_client',
     'get_server',
     'get_notifier',
+    'TRANSPORT_ALIASES',
 ]
 
+from oslo.config import cfg
+from oslo import messaging
+from oslo.messaging import server as msg_server
+from oslo.messaging.rpc import dispatcher as rpc_dispatcher
+from oslo.serialization import jsonutils
+
+import designate.context
+import designate.exceptions
+from designate import objects
+
+
 CONF = cfg.CONF
-NOTIFICATION_TRANSPORT = None
-NOTIFIER = None
 TRANSPORT = None
+NOTIFIER = None
+
 
 # NOTE: Additional entries to designate.exceptions goes here.
+CONF.register_opts([
+    cfg.ListOpt(
+        'allowed_remote_exmods',
+        default=[],
+        help="Additional modules that contains allowed RPC exceptions.",
+        deprecated_name='allowed_rpc_exception_modules')
+])
 ALLOWED_EXMODS = [
     designate.exceptions.__name__,
     'designate.backend.impl_dynect'
@@ -50,32 +57,40 @@ ALLOWED_EXMODS = [
 EXTRA_EXMODS = []
 
 
+# NOTE(flaper87): The designate.openstack.common.rpc entries are
+# for backwards compat with Havana rpc_backend configuration
+# values. The designate.rpc entries are for compat with Folsom values.
+TRANSPORT_ALIASES = {
+    'designate.openstack.common.rpc.impl_kombu': 'rabbit',
+    'designate.openstack.common.rpc.impl_qpid': 'qpid',
+    'designate.openstack.common.rpc.impl_zmq': 'zmq',
+    'designate.rpc.impl_kombu': 'rabbit',
+    'designate.rpc.impl_qpid': 'qpid',
+    'designate.rpc.impl_zmq': 'zmq',
+}
+
+
 def init(conf):
-    global TRANSPORT, NOTIFIER, NOTIFICATION_TRANSPORT
+    global TRANSPORT, NOTIFIER
     exmods = get_allowed_exmods()
-    TRANSPORT = create_transport(get_transport_url())
-    NOTIFICATION_TRANSPORT = messaging.get_notification_transport(
-        conf, allowed_remote_exmods=exmods)
+    TRANSPORT = messaging.get_transport(conf,
+                                        allowed_remote_exmods=exmods,
+                                        aliases=TRANSPORT_ALIASES)
+
     serializer = RequestContextSerializer(JsonPayloadSerializer())
-    NOTIFIER = messaging.Notifier(NOTIFICATION_TRANSPORT,
-                                  serializer=serializer)
+    NOTIFIER = messaging.Notifier(TRANSPORT, serializer=serializer)
 
 
 def initialized():
-    return None not in [TRANSPORT, NOTIFIER, NOTIFICATION_TRANSPORT]
+    return None not in [TRANSPORT, NOTIFIER]
 
 
 def cleanup():
-    global TRANSPORT, NOTIFIER, NOTIFICATION_TRANSPORT
-    if TRANSPORT is None:
-        raise AssertionError("'TRANSPORT' must not be None")
-    if NOTIFICATION_TRANSPORT is None:
-        raise AssertionError("'NOTIFICATION_TRANSPORT' must not be None")
-    if NOTIFIER is None:
-        raise AssertionError("'NOTIFIER' must not be None")
+    global TRANSPORT, NOTIFIER
+    assert TRANSPORT is not None
+    assert NOTIFIER is not None
     TRANSPORT.cleanup()
-    NOTIFICATION_TRANSPORT.cleanup()
-    TRANSPORT = NOTIFICATION_TRANSPORT = NOTIFIER = None
+    TRANSPORT = NOTIFIER = None
 
 
 def set_defaults(control_exchange):
@@ -151,86 +166,61 @@ class RequestContextSerializer(messaging.Serializer):
         return self._base.deserialize_entity(context, entity)
 
     def serialize_context(self, context):
-        _context = context.to_dict()
-        if profiler is not None:
-            prof = profiler.get()
-            if prof is not None:
-                trace_info = {
-                    "hmac_key": prof.hmac_key,
-                    "base_id": prof.get_base_id(),
-                    "parent_id": prof.get_id()
-                }
-                _context.update({"trace_info": trace_info})
-        return _context
+        return context.to_dict()
 
     def deserialize_context(self, context):
-        trace_info = context.pop("trace_info", None)
-        if trace_info is not None:
-            if profiler is not None:
-                profiler.init(**trace_info)
         return designate.context.DesignateContext.from_dict(context)
 
 
+class RPCDispatcher(rpc_dispatcher.RPCDispatcher):
+    def _dispatch(self, *args, **kwds):
+        try:
+            return super(RPCDispatcher, self)._dispatch(*args, **kwds)
+        except Exception as e:
+            if getattr(e, 'expected', False):
+                raise rpc_dispatcher.ExpectedException()
+            else:
+                raise
+
+
 def get_transport_url(url_str=None):
-    return messaging.TransportURL.parse(CONF, url_str)
+    return messaging.TransportURL.parse(CONF, url_str, TRANSPORT_ALIASES)
 
 
 def get_client(target, version_cap=None, serializer=None):
-    if TRANSPORT is None:
-        raise AssertionError("'TRANSPORT' must not be None")
+    assert TRANSPORT is not None
     if serializer is None:
         serializer = DesignateObjectSerializer()
     serializer = RequestContextSerializer(serializer)
-    return messaging.get_rpc_client(
-        TRANSPORT,
-        target,
-        version_cap=version_cap,
-        serializer=serializer
-    )
+    return messaging.RPCClient(TRANSPORT,
+                               target,
+                               version_cap=version_cap,
+                               serializer=serializer)
 
 
 def get_server(target, endpoints, serializer=None):
-    if TRANSPORT is None:
-        raise AssertionError("'TRANSPORT' must not be None")
+    assert TRANSPORT is not None
     if serializer is None:
         serializer = DesignateObjectSerializer()
     serializer = RequestContextSerializer(serializer)
-    access_policy = rpc_dispatcher.DefaultRPCAccessPolicy
-    return messaging.get_rpc_server(
-        TRANSPORT,
-        target,
-        endpoints,
-        executor='eventlet',
-        serializer=serializer,
-        access_policy=access_policy
-    )
+
+    dispatcher = RPCDispatcher(target, endpoints, serializer)
+    return msg_server.MessageHandlingServer(TRANSPORT, dispatcher, 'eventlet')
 
 
-def get_notification_listener(targets, endpoints, serializer=None, pool=None):
-    if NOTIFICATION_TRANSPORT is None:
-        raise AssertionError("'NOTIFICATION_TRANSPORT' must not be None")
+def get_listener(targets, endpoints, serializer=None):
+    assert TRANSPORT is not None
     if serializer is None:
         serializer = JsonPayloadSerializer()
-    return messaging.get_notification_listener(
-        NOTIFICATION_TRANSPORT,
-        targets,
-        endpoints,
-        executor='eventlet',
-        pool=pool,
-        serializer=serializer
-    )
+    return messaging.get_notification_listener(TRANSPORT,
+                                               targets,
+                                               endpoints,
+                                               executor='eventlet',
+                                               serializer=serializer)
 
 
 def get_notifier(service=None, host=None, publisher_id=None):
-    if NOTIFIER is None:
-        raise AssertionError("'NOTIFIER' must not be None")
+    assert NOTIFIER is not None
     if not publisher_id:
         publisher_id = "%s.%s" % (service, host or CONF.host)
     return NOTIFIER.prepare(publisher_id=publisher_id)
-
-
-def create_transport(url):
-    exmods = get_allowed_exmods()
-    return messaging.get_rpc_transport(CONF,
-                                       url=url,
-                                       allowed_remote_exmods=exmods)
