@@ -16,10 +16,10 @@
 from oslo_log import log as logging
 
 from designate import exceptions
-from designate.schema import format
-from designate.schema import resolvers
-from designate.schema import validators
 from designate import utils
+from designate.schema import validators
+from designate.schema import resolvers
+from designate.schema import format
 
 LOG = logging.getLogger(__name__)
 
@@ -30,7 +30,11 @@ class Schema(object):
         self.resolver = resolvers.LocalResolver.from_schema(
             version, self.raw_schema)
 
-        if version in ['v2', 'admin']:
+        if version == 'v1':
+            self.validator = validators.Draft3Validator(
+                self.raw_schema, resolver=self.resolver,
+                format_checker=format.draft3_format_checker)
+        elif version in ['v2', 'admin']:
             self.validator = validators.Draft4Validator(
                 self.raw_schema, resolver=self.resolver,
                 format_checker=format.draft4_format_checker)
@@ -75,7 +79,7 @@ class Schema(object):
 
         filtered = {}
 
-        for name, subschema in list(properties.items()):
+        for name, subschema in properties.items():
             if 'type' in subschema and subschema['type'] == 'array':
                 subinstance = instance.get(name, None)
                 filtered[name] = self._filter_array(subinstance, subschema)
@@ -108,7 +112,7 @@ class Schema(object):
             schema = schema['properties']
 
             with self.resolver.resolving(schema['$ref']) as ischema:
-                schema = ischema
+                    schema = ischema
 
             return [self.filter(i, schema) for i in instance]
 
