@@ -1,6 +1,6 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 #
-# Author: Kiall Mac Innes <kiall@hpe.com>
+# Author: Kiall Mac Innes <kiall@hp.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -24,7 +24,7 @@ LOG = logging.getLogger(__name__)
 
 class LocalResolver(jsonschema.RefResolver):
     def __init__(self, base_uri, referrer):
-        super(LocalResolver, self).__init__(base_uri, referrer)
+        super(LocalResolver, self).__init__(base_uri, referrer, (), True)
         self.api_version = None
 
     @classmethod
