@@ -13,7 +13,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
+from oslo.config import cfg
 from oslo_utils import timeutils
 
 from sqlalchemy import Integer, String, DateTime, Unicode, UniqueConstraint, \
