@@ -14,7 +14,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
+from oslo.config import cfg
 
 from designate.tests.test_api.test_admin import AdminApiTestCase
 
@@ -40,15 +40,14 @@ class AdminApiQuotasTest(AdminApiTestCase):
 
         self.assertIn('quota', response.json)
         self.assertIn('zones', response.json['quota'])
-        self.assertIn('api_export_size', response.json['quota'])
         self.assertIn('zone_records', response.json['quota'])
         self.assertIn('zone_recordsets', response.json['quota'])
         self.assertIn('recordset_records', response.json['quota'])
 
         max_zones = response.json['quota']['zones']
         max_zone_records = response.json['quota']['zone_records']
-        self.assertEqual(cfg.CONF.quota_zones, max_zones)
-        self.assertEqual(cfg.CONF.quota_zone_records, max_zone_records)
+        self.assertEqual(cfg.CONF.quota_domains, max_zones)
+        self.assertEqual(cfg.CONF.quota_domain_records, max_zone_records)
 
     def test_patch_quotas(self):
         self.policy({'set_quotas': '@'})
