@@ -14,9 +14,13 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import datetime
+
 from mock import patch
-from designate.openstack.common import log as logging
-from designate.openstack.common.rpc import common as rpc_common
+from oslo import messaging
+from oslo.config import cfg
+from oslo_log import log as logging
+
 from designate import exceptions
 from designate.central import service as central_service
 from designate.tests.test_api.test_v1 import ApiV1Test
@@ -26,34 +30,20 @@ LOG = logging.getLogger(__name__)
 
 
 class ApiV1DomainsTest(ApiV1Test):
-    __test__ = True
-
     def test_create_domain(self):
-        # Create a server
-        self.create_server()
-
         # Create a domain
         fixture = self.get_domain_fixture(0)
 
+        # V1 doesn't have these
+        del fixture['type']
+
         response = self.post('domains', data=fixture)
 
         self.assertIn('id', response.json)
         self.assertIn('name', response.json)
         self.assertEqual(response.json['name'], fixture['name'])
 
-    @patch.object(central_service.Service, 'create_domain')
-    def test_create_domain_trailing_slash(self, mock):
-        # Create a server
-        self.create_server()
-        self.post('domains/', data=self.get_domain_fixture(0))
-
-        # verify that the central service is called
-        self.assertTrue(mock.called)
-
     def test_create_domain_junk(self):
-        # Create a server
-        self.create_server()
-
         # Create a domain
         fixture = self.get_domain_fixture(0)
 
@@ -63,18 +53,15 @@ class ApiV1DomainsTest(ApiV1Test):
         # Ensure it fails with a 400
         self.post('domains', data=fixture, status_code=400)
 
-    def test_create_domain_no_servers(self):
-        # Create a domain
-        fixture = self.get_domain_fixture(0)
-
-        self.post('domains', data=fixture, status_code=500)
-
     @patch.object(central_service.Service, 'create_domain',
-                  side_effect=rpc_common.Timeout())
+                  side_effect=messaging.MessagingTimeout())
     def test_create_domain_timeout(self, _):
         # Create a domain
         fixture = self.get_domain_fixture(0)
 
+        # V1 doesn't have these
+        del fixture['type']
+
         self.post('domains', data=fixture, status_code=504)
 
     @patch.object(central_service.Service, 'create_domain',
@@ -82,6 +69,10 @@ class ApiV1DomainsTest(ApiV1Test):
     def test_create_domain_duplicate(self, _):
         # Create a domain
         fixture = self.get_domain_fixture(0)
+
+        # V1 doesn't have these
+        del fixture['type']
+
         self.post('domains', data=fixture, status_code=409)
 
     def test_create_domain_null_ttl(self):
@@ -96,28 +87,47 @@ class ApiV1DomainsTest(ApiV1Test):
         fixture['ttl'] = -1
         self.post('domains', data=fixture, status_code=400)
 
-    def test_create_domain_utf_description(self):
-        # Create a server
-        self.create_server()
+    def test_create_domain_invalid_ttl(self):
+        # Create a domain
+        fixture = self.get_domain_fixture(0)
+        fixture['ttl'] = "$?>&"
+        self.post('domains', data=fixture, status_code=400)
 
+    def test_create_domain_utf_description(self):
         # Create a domain
         fixture = self.get_domain_fixture(0)
 
-        #Give it a UTF-8 filled description
+        # V1 doesn't have type
+        del fixture['type']
+
+        # Give it a UTF-8 filled description
         fixture['description'] = "utf-8:2H₂+O₂⇌2H₂O,R=4.7kΩ,⌀200mm∮E⋅da=Q,n" \
                                  ",∑f(i)=∏g(i),∀x∈ℝ:⌈x⌉"
-        #Create the domain, ensuring it suceeds, thus UTF-8 is supported
+        # Create the domain, ensuring it succeeds, thus UTF-8 is supported
         self.post('domains', data=fixture)
 
     def test_create_domain_description_too_long(self):
-        # Create a server
-        self.create_server()
-
         # Create a domain
         fixture = self.get_domain_fixture(0)
         fixture['description'] = "x" * 161
 
-        #Create the domain, ensuring it fails with a 400
+        # Create the domain, ensuring it fails with a 400
+        self.post('domains', data=fixture, status_code=400)
+
+    def test_create_domain_with_unwanted_attributes(self):
+
+        domain_id = "2d1d1d1d-1324-4a80-aa32-1f69a91bf2c8"
+        created_at = datetime.datetime(2014, 6, 22, 21, 50, 0)
+        updated_at = datetime.datetime(2014, 6, 22, 21, 50, 0)
+        serial = 1234567
+
+        # Create a domain
+        fixture = self.get_domain_fixture(0)
+        fixture['id'] = domain_id
+        fixture['created_at'] = created_at
+        fixture['updated_at'] = updated_at
+        fixture['serial'] = serial
+
         self.post('domains', data=fixture, status_code=400)
 
     def test_create_invalid_name(self):
@@ -182,15 +192,15 @@ class ApiV1DomainsTest(ApiV1Test):
         self.assertIn('domains', response.json)
         self.assertEqual(2, len(response.json['domains']))
 
-    @patch.object(central_service.Service, 'find_domains')
-    def test_get_domains_trailing_slash(self, mock):
-        self.get('domains/')
-
-        # verify that the central service is called
-        self.assertTrue(mock.called)
+    def test_get_domain_servers(self):
+        # Create a domain
+        domain = self.create_domain()
+        response = self.get('domains/%s/servers' % domain['id'])
+        # Verify length of domain servers
+        self.assertEqual(1, len(response.json['servers']))
 
     @patch.object(central_service.Service, 'find_domains',
-                  side_effect=rpc_common.Timeout())
+                  side_effect=messaging.MessagingTimeout())
     def test_get_domains_timeout(self, _):
         self.get('domains', status_code=504)
 
@@ -203,18 +213,8 @@ class ApiV1DomainsTest(ApiV1Test):
         self.assertIn('id', response.json)
         self.assertEqual(response.json['id'], domain['id'])
 
-    @patch.object(central_service.Service, 'get_domain')
-    def test_get_domain_trailing_slash(self, mock):
-        # Create a domain
-        domain = self.create_domain()
-
-        self.get('domains/%s/' % domain['id'])
-
-        # verify that the central service is called
-        self.assertTrue(mock.called)
-
-    @patch.object(central_service.Service, 'get_domain',
-                  side_effect=rpc_common.Timeout())
+    @patch.object(central_service.Service, 'find_domain',
+                  side_effect=messaging.MessagingTimeout())
     def test_get_domain_timeout(self, _):
         # Create a domain
         domain = self.create_domain()
@@ -246,18 +246,6 @@ class ApiV1DomainsTest(ApiV1Test):
         self.assertIn('email', response.json)
         self.assertEqual(response.json['email'], 'prefix-%s' % domain['email'])
 
-    @patch.object(central_service.Service, 'update_domain')
-    def test_update_domain_trailing_slash(self, mock):
-        # Create a domain
-        domain = self.create_domain()
-
-        data = {'email': 'prefix-%s' % domain['email']}
-
-        self.put('domains/%s/' % domain['id'], data=data)
-
-        # verify that the central service is called
-        self.assertTrue(mock.called)
-
     def test_update_domain_junk(self):
         # Create a domain
         domain = self.create_domain()
@@ -282,8 +270,16 @@ class ApiV1DomainsTest(ApiV1Test):
 
         self.put('domains/%s' % domain['id'], data=data, status_code=400)
 
+    def test_update_domain_negative_ttl(self):
+        # Create a domain
+        domain = self.create_domain()
+
+        data = {'ttl': -1}
+
+        self.put('domains/%s' % domain['id'], data=data, status_code=400)
+
     @patch.object(central_service.Service, 'update_domain',
-                  side_effect=rpc_common.Timeout())
+                  side_effect=messaging.MessagingTimeout())
     def test_update_domain_timeout(self, _):
         # Create a domain
         domain = self.create_domain()
@@ -324,21 +320,17 @@ class ApiV1DomainsTest(ApiV1Test):
 
         self.delete('domains/%s' % domain['id'])
 
-        # Esnure we can no longer fetch the domain
+        # Simulate the domain having been deleted on the backend
+        domain_serial = self.central_service.get_domain(
+            self.admin_context, domain['id']).serial
+        self.central_service.update_status(
+            self.admin_context, domain['id'], "SUCCESS", domain_serial)
+
+        # Ensure we can no longer fetch the domain
         self.get('domains/%s' % domain['id'], status_code=404)
 
-    @patch.object(central_service.Service, 'delete_domain')
-    def test_delete_domain_trailing_slash(self, mock):
-        # Create a domain
-        domain = self.create_domain()
-
-        self.delete('domains/%s/' % domain['id'])
-
-        # verify that the central service is called
-        self.assertTrue(mock.called)
-
     @patch.object(central_service.Service, 'delete_domain',
-                  side_effect=rpc_common.Timeout())
+                  side_effect=messaging.MessagingTimeout())
     def test_delete_domain_timeout(self, _):
         # Create a domain
         domain = self.create_domain()
@@ -356,3 +348,33 @@ class ApiV1DomainsTest(ApiV1Test):
 
         self.delete('domains/2fdadfb1cf964259ac6bbb7b6d2ff980',
                     status_code=404)
+
+    def test_get_secondary_missing(self):
+        fixture = self.get_domain_fixture('SECONDARY', 0)
+        fixture['email'] = cfg.CONF['service:central'].managed_resource_email
+
+        domain = self.create_domain(**fixture)
+
+        self.get('domains/%s' % domain.id, status_code=404)
+
+    def test_update_secondary_missing(self):
+        fixture = self.get_domain_fixture('SECONDARY', 0)
+        fixture['email'] = cfg.CONF['service:central'].managed_resource_email
+
+        domain = self.create_domain(**fixture)
+
+        self.put('domains/%s' % domain.id, {}, status_code=404)
+
+    def test_delete_secondary_missing(self):
+        fixture = self.get_domain_fixture('SECONDARY', 0)
+        fixture['email'] = cfg.CONF['service:central'].managed_resource_email
+
+        domain = self.create_domain(**fixture)
+        self.delete('domains/%s' % domain.id, status_code=404)
+
+    def test_get_domain_servers_from_secondary(self):
+        fixture = self.get_domain_fixture('SECONDARY', 0)
+        fixture['email'] = cfg.CONF['service:central'].managed_resource_email
+
+        domain = self.create_domain(**fixture)
+        self.get('domains/%s/servers' % domain.id, status_code=404)
