@@ -13,22 +13,22 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import binascii
-from unittest import mock
-from unittest.mock import patch
 
 import dns
-import dns.exception
 import dns.message
 import dns.query
+import dns.exception
+import mock
+from mock import patch
 
+from designate.tests.test_mdns import MdnsTestCase
 from designate.mdns import notify
 from designate import objects
-from designate.tests.test_mdns import MdnsTestCase
 
 
 class MdnsNotifyTest(MdnsTestCase):
 
-    test_zone = {
+    test_domain = {
         'name': 'example.com.',
         'email': 'example@example.com',
         'serial': 100,
@@ -60,8 +60,8 @@ class MdnsNotifyTest(MdnsTestCase):
         with patch.object(dns.query, 'udp', return_value=dns.message.from_wire(
                 binascii.a2b_hex(expected_notify_response))):
             response, retry = self.notify.notify_zone_changed(
-                context, objects.Zone.from_dict(self.test_zone),
-                self.nameserver.host, self.nameserver.port, 0, 0, 2, 0)
+                context, objects.Domain.from_dict(self.test_domain),
+                self.nameserver, 0, 0, 2, 0)
             self.assertEqual(response, dns.message.from_wire(
                 binascii.a2b_hex(expected_notify_response)))
             self.assertEqual(retry, 1)
@@ -82,27 +82,27 @@ class MdnsNotifyTest(MdnsTestCase):
         with patch.object(dns.query, 'udp', return_value=dns.message.from_wire(
                 binascii.a2b_hex(non_auth_notify_response))):
             response, retry = self.notify.notify_zone_changed(
-                context, objects.Zone.from_dict(self.test_zone),
-                self.nameserver.host, self.nameserver.port, 0, 0, 2, 0)
-            self.assertIsNone(response)
+                context, objects.Domain.from_dict(self.test_domain),
+                self.nameserver, 0, 0, 2, 0)
+            self.assertEqual(response, None)
             self.assertEqual(retry, 1)
 
     @patch.object(dns.query, 'udp', side_effect=dns.exception.Timeout)
     def test_send_notify_message_timeout(self, _):
         context = self.get_context()
         response, retry = self.notify.notify_zone_changed(
-            context, objects.Zone.from_dict(self.test_zone),
-            self.nameserver.host, self.nameserver.port, 0, 0, 2, 0)
-        self.assertIsNone(response)
+            context, objects.Domain.from_dict(self.test_domain),
+            self.nameserver, 0, 0, 2, 0)
+        self.assertEqual(response, None)
         self.assertEqual(retry, 2)
 
     @patch.object(dns.query, 'udp', side_effect=dns.query.BadResponse)
     def test_send_notify_message_bad_response(self, _):
         context = self.get_context()
         response, retry = self.notify.notify_zone_changed(
-            context, objects.Zone.from_dict(self.test_zone),
-            self.nameserver.host, self.nameserver.port, 0, 0, 2, 0)
-        self.assertIsNone(response)
+            context, objects.Domain.from_dict(self.test_domain),
+            self.nameserver, 0, 0, 2, 0)
+        self.assertEqual(response, None)
         self.assertEqual(retry, 1)
 
     def test_poll_for_serial_number(self):
@@ -125,10 +125,10 @@ class MdnsNotifyTest(MdnsTestCase):
         with patch.object(dns.query, 'udp', return_value=dns.message.from_wire(
                 binascii.a2b_hex(poll_response))):
             status, serial, retries = self.notify.get_serial_number(
-                context, objects.Zone.from_dict(self.test_zone),
-                self.nameserver.host, self.nameserver.port, 0, 0, 2, 0)
+                context, objects.Domain.from_dict(self.test_domain),
+                self.nameserver, 0, 0, 2, 0)
             self.assertEqual(status, 'SUCCESS')
-            self.assertEqual(serial, self.test_zone['serial'])
+            self.assertEqual(serial, self.test_domain['serial'])
             self.assertEqual(retries, 2)
 
     def test_poll_for_serial_number_lower_serial(self):
@@ -151,8 +151,8 @@ class MdnsNotifyTest(MdnsTestCase):
         with patch.object(dns.query, 'udp', return_value=dns.message.from_wire(
                 binascii.a2b_hex(poll_response))):
             status, serial, retries = self.notify.get_serial_number(
-                context, objects.Zone.from_dict(self.test_zone),
-                self.nameserver.host, self.nameserver.port, 0, 0, 2, 0)
+                context, objects.Domain.from_dict(self.test_domain),
+                self.nameserver, 0, 0, 2, 0)
             self.assertEqual(status, 'ERROR')
             self.assertEqual(serial, 99)
             self.assertEqual(retries, 0)
@@ -177,8 +177,8 @@ class MdnsNotifyTest(MdnsTestCase):
         with patch.object(dns.query, 'udp', return_value=dns.message.from_wire(
                 binascii.a2b_hex(poll_response))):
             status, serial, retries = self.notify.get_serial_number(
-                context, objects.Zone.from_dict(self.test_zone),
-                self.nameserver.host, self.nameserver.port, 0, 0, 2, 0)
+                context, objects.Domain.from_dict(self.test_domain),
+                self.nameserver, 0, 0, 2, 0)
             self.assertEqual(status, 'SUCCESS')
             self.assertEqual(serial, 101)
             self.assertEqual(retries, 2)
@@ -187,10 +187,10 @@ class MdnsNotifyTest(MdnsTestCase):
     def test_poll_for_serial_number_timeout(self, _):
         context = self.get_context()
         status, serial, retries = self.notify.get_serial_number(
-            context, objects.Zone.from_dict(self.test_zone),
-            self.nameserver.host, self.nameserver.port, 0, 0, 2, 0)
+            context, objects.Domain.from_dict(self.test_domain),
+            self.nameserver, 0, 0, 2, 0)
         self.assertEqual(status, 'ERROR')
-        self.assertIsNone(serial)
+        self.assertEqual(serial, None)
         self.assertEqual(retries, 0)
 
     @patch('dns.query.udp', side_effect=dns.exception.Timeout)
@@ -201,12 +201,10 @@ class MdnsNotifyTest(MdnsTestCase):
             group='service:mdns'
         )
         context = self.get_context()
-        test_zone = objects.Zone.from_dict(self.test_zone)
+        test_domain = objects.Domain.from_dict(self.test_domain)
         status, serial, retries = self.notify.get_serial_number(
-            context, test_zone, self.nameserver.host,
-            self.nameserver.port, 0, 0, 2, 0)
+            context, test_domain, self.nameserver, 0, 0, 2, 0)
         response, retry = self.notify.notify_zone_changed(
-            context, test_zone, self.nameserver.host,
-            self.nameserver.port, 0, 0, 2, 0)
+            context, test_domain, self.nameserver, 0, 0, 2, 0)
         assert not udp.called
         assert tcp.called
