@@ -13,7 +13,8 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from designate.openstack.common import log as logging
+from oslo_log import log as logging
+
 from designate.tests import TestCase
 from designate.notification_handler.nova import NovaFixedHandler
 from designate.tests.test_notification_handler import \
@@ -72,7 +73,7 @@ class NovaFixedHandlerTest(TestCase, NotificationHandlerMixin):
 
         criterion = {'domain_id': self.domain_id}
 
-        # Ensure we start with at least 1 record
+        # Ensure we start with at least 1 record, plus NS and SOA
         records = self.central_service.find_records(self.admin_context,
                                                     criterion)
 
@@ -81,7 +82,13 @@ class NovaFixedHandlerTest(TestCase, NotificationHandlerMixin):
         self.plugin.process_notification(
             self.admin_context, event_type, fixture['payload'])
 
-        # Ensure we now have exactly 0 records
+        # Simulate the record having been deleted on the backend
+        domain_serial = self.central_service.get_domain(
+            self.admin_context, self.domain_id).serial
+        self.central_service.update_status(
+            self.admin_context, self.domain_id, "SUCCESS", domain_serial)
+
+        # Ensure we now have exactly 0 records, plus NS and SOA
         records = self.central_service.find_records(self.admin_context,
                                                     criterion)
 
